@@ -73,7 +73,8 @@ _gedit_cmd_file_new (GtkAction   *action,
 }
 
 static GeditTab *
-get_tab_from_file (GList *docs, GFile *file)
+get_tab_from_file (GList *docs,
+		   GFile *file)
 {
 	GeditTab *tab = NULL;
 
@@ -104,7 +105,8 @@ get_tab_from_file (GList *docs, GFile *file)
 }
 
 static gboolean
-is_duplicated_file (GSList *files, GFile *file)
+is_duplicated_file (GSList *files,
+		    GFile  *file)
 {
 	while (files != NULL)
 	{
@@ -118,7 +120,7 @@ is_duplicated_file (GSList *files, GFile *file)
 }
 
 /* File loading */
-static gint
+static GSList *
 load_file_list (GeditWindow         *window,
 		const GSList        *files,
 		const GeditEncoding *encoding,
@@ -127,11 +129,12 @@ load_file_list (GeditWindow         *window,
 		gboolean             create)
 {
 	GeditTab      *tab;
-	gint           loaded_files = 0; /* Number of files to load */
+	GSList        *loaded_files = NULL; /* Number of files to load */
 	gboolean       jump_to = TRUE; /* Whether to jump to the new tab */
 	GList         *win_docs;
 	GSList        *files_to_load = NULL;
 	const GSList  *l;
+	gint num_loaded_files = 0;
 
 	gedit_debug (DEBUG_COMMANDS);
 
@@ -148,24 +151,38 @@ load_file_list (GeditWindow         *window,
 			{
 				if (l == files)
 				{
+					GeditDocument *doc;
+
 					gedit_window_set_active_tab (window, tab);
 					jump_to = FALSE;
+					doc = gedit_tab_get_document (tab);
 
 					if (line_pos > 0)
 					{
-						GeditDocument *doc;
-						GeditView *view;
-
-						doc = gedit_tab_get_document (tab);
-						view = gedit_tab_get_view (tab);
-
 						/* document counts lines starting from 0 */
-						gedit_document_goto_line (doc, line_pos - 1);
-						gedit_view_scroll_to_cursor (view);
+						if (column_pos > 0)
+						{
+							GtkTextIter iter;
+
+							gtk_text_buffer_get_iter_at_line_offset (GTK_TEXT_BUFFER (doc),
+							                                         &iter,
+							                                         line_pos - 1,
+							                                         column_pos - 1);
+
+							gtk_text_buffer_place_cursor (GTK_TEXT_BUFFER (doc), &iter);
+						}
+						else
+						{
+							gedit_document_goto_line (doc, line_pos - 1);
+						}
+
+						gedit_view_scroll_to_cursor (gedit_tab_get_view (tab));
 					}
 				}
 
-				++loaded_files;
+				++num_loaded_files;
+				loaded_files = g_slist_prepend (loaded_files,
+				                                gedit_tab_get_document (tab));
 			}
 			else
 			{
@@ -178,8 +195,10 @@ load_file_list (GeditWindow         *window,
 	g_list_free (win_docs);
 
 	if (files_to_load == NULL)
-		return loaded_files;
-	
+	{
+		return g_slist_reverse (loaded_files);
+	}
+
 	files_to_load = g_slist_reverse (files_to_load);
 	l = files_to_load;
 
@@ -206,7 +225,9 @@ load_file_list (GeditWindow         *window,
 			l = g_slist_next (l);
 			jump_to = FALSE;
 
-			++loaded_files;
+			++num_loaded_files;
+			loaded_files = g_slist_prepend (loaded_files,
+			                                gedit_tab_get_document (tab));
 		}
 	}
 
@@ -225,13 +246,18 @@ load_file_list (GeditWindow         *window,
 		if (tab != NULL)
 		{
 			jump_to = FALSE;
-			++loaded_files;
+
+			++num_loaded_files;
+			loaded_files = g_slist_prepend (loaded_files,
+			                                gedit_tab_get_document (tab));
 		}
 
 		l = g_slist_next (l);
 	}
 
-	if (loaded_files == 1)
+	loaded_files = g_slist_reverse (loaded_files);
+
+	if (num_loaded_files == 1)
 	{
 		GeditDocument *doc;
 		gchar *uri_for_display;
@@ -254,8 +280,8 @@ load_file_list (GeditWindow         *window,
 					       window->priv->generic_message_cid,
 					       ngettext("Loading %d file\342\200\246",
 							"Loading %d files\342\200\246",
-							loaded_files),
-					       loaded_files);
+							num_loaded_files),
+					       num_loaded_files);
 	}
 
 	/* Free uris_to_load. Note that l points to the first element of uris_to_load */
@@ -278,6 +304,7 @@ gedit_commands_load_location (GeditWindow         *window,
 {
 	GSList *locations = NULL;
 	gchar *uri;
+	GSList *ret;
 
 	g_return_if_fail (GEDIT_IS_WINDOW (window));
 	g_return_if_fail (G_IS_FILE (location));
@@ -289,7 +316,8 @@ gedit_commands_load_location (GeditWindow         *window,
 
 	locations = g_slist_prepend (locations, location);
 
-	load_file_list (window, locations, encoding, line_pos, column_pos, FALSE);
+	ret = load_file_list (window, locations, encoding, line_pos, column_pos, FALSE);
+	g_slist_free (ret);
 
 	g_slist_free (locations);
 }
@@ -299,7 +327,7 @@ gedit_commands_load_location (GeditWindow         *window,
  *
  * Ignore non-existing locations 
  */
-gint
+GSList *
 gedit_commands_load_locations (GeditWindow         *window,
 			       const GSList        *locations,
 			       const GeditEncoding *encoding,
@@ -319,7 +347,7 @@ gedit_commands_load_locations (GeditWindow         *window,
  * first doc. Beside specifying a not existing uri creates a
  * titled document.
  */
-gint
+GSList *
 _gedit_cmd_load_files_from_prompt (GeditWindow         *window,
 				   GSList              *files,
 				   const GeditEncoding *encoding,
@@ -349,6 +377,7 @@ open_dialog_response_cb (GeditFileChooserDialog *dialog,
 {
 	GSList *files;
 	const GeditEncoding *encoding;
+	GSList *loaded;
 
 	gedit_debug (DEBUG_COMMANDS);
 
@@ -369,11 +398,13 @@ open_dialog_response_cb (GeditFileChooserDialog *dialog,
 	/* Remember the folder we navigated to */
 	 _gedit_window_set_default_location (window, files->data);
 
-	gedit_commands_load_locations (window,
-				       files,
-				       encoding,
-				       0,
-				       0);
+	loaded = gedit_commands_load_locations (window,
+	                                        files,
+	                                        encoding,
+	                                        0,
+	                                        0);
+
+	g_slist_free (loaded);
 
 	g_slist_foreach (files, (GFunc) g_object_unref, NULL);
 	g_slist_free (files);
@@ -457,7 +488,8 @@ _gedit_cmd_file_open (GtkAction   *action,
 }
 
 /* File saving */
-static void file_save_as (GeditTab *tab, GeditWindow *window);
+static void file_save_as (GeditTab    *tab,
+			  GeditWindow *window);
 
 static gboolean
 is_read_only (GFile *location)
@@ -491,7 +523,8 @@ is_read_only (GFile *location)
 /* FIXME: modify this dialog to be similar to the one provided by gtk+ for
  * already existing files - Paolo (Oct. 11, 2005) */
 static gboolean
-replace_read_only_file (GtkWindow *parent, GFile *file)
+replace_read_only_file (GtkWindow *parent,
+			GFile     *file)
 {
 	GtkWidget *dialog;
 	gint ret;
@@ -542,17 +575,106 @@ replace_read_only_file (GtkWindow *parent, GFile *file)
 	return (ret == GTK_RESPONSE_YES);
 }
 
+static gboolean
+change_compression (GtkWindow *parent,
+                    GFile     *file,
+                    gboolean   compressed)
+{
+	GtkWidget *dialog;
+	gint ret;
+	gchar *parse_name;
+	gchar *name_for_display;
+	const gchar *primary_message;
+	const gchar *secondary_message;
+	const gchar *button_label;
+
+	gedit_debug (DEBUG_COMMANDS);
+
+	parse_name = g_file_get_parse_name (file);
+
+	/* Truncate the name so it doesn't get insanely wide. Note that even
+	 * though the dialog uses wrapped text, if the name doesn't contain
+	 * white space then the text-wrapping code is too stupid to wrap it.
+	 */
+	name_for_display = gedit_utils_str_middle_truncate (parse_name, 50);
+	g_free (parse_name);
+
+	if (compressed)
+	{
+		primary_message = _("Save the file using compression?");
+		secondary_message = _("The file \"%s\" was previously saved as plain "
+		                      "text and will now be saved using compression.");
+		button_label = _("_Save Using Compression");
+	}
+	else
+	{
+		primary_message = _("Save the file as plain text?");
+		secondary_message = _("The file \"%s\" was previously saved "
+		                      "using compression and will now be saved as plain text.");
+		button_label = _("_Save As Plain Text");
+	}
+
+	dialog = gtk_message_dialog_new (parent,
+					 GTK_DIALOG_DESTROY_WITH_PARENT,
+					 GTK_MESSAGE_QUESTION,
+					 GTK_BUTTONS_NONE,
+					 "%s",
+					 primary_message);
+
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+						  secondary_message,
+						  name_for_display);
+
+	g_free (name_for_display);
+
+	gtk_dialog_add_button (GTK_DIALOG (dialog),
+			       GTK_STOCK_CANCEL,
+			       GTK_RESPONSE_CANCEL);
+
+	gedit_dialog_add_button (GTK_DIALOG (dialog),
+				 button_label,
+			  	 GTK_STOCK_SAVE_AS,
+			  	 GTK_RESPONSE_YES);
+
+	gtk_dialog_set_default_response	(GTK_DIALOG (dialog),
+					 GTK_RESPONSE_CANCEL);
+
+	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+
+	ret = gtk_dialog_run (GTK_DIALOG (dialog));
+
+	gtk_widget_destroy (dialog);
+
+	return (ret == GTK_RESPONSE_YES);
+}
+
+static GeditDocumentCompressionType
+get_compression_type_from_file (GFile *file)
+{
+	gchar *name;
+	gchar *content_type;
+	GeditDocumentCompressionType type;
+
+	name = g_file_get_basename (file);
+	content_type = g_content_type_guess (name, NULL, 0, NULL);
+
+	type = gedit_utils_get_compression_type_from_content_type (content_type);
+
+	g_free (name);
+	g_free (content_type);
+
+	return type;
+}
+
 static void
 save_dialog_response_cb (GeditFileChooserDialog *dialog,
                          gint                    response_id,
                          GeditWindow            *window)
 {
 	GFile *file;
-	const GeditEncoding *encoding;
 	GeditTab *tab;
 	gpointer data;
 	GSList *tabs_to_save_as;
-	GeditDocumentNewlineType newline_type;
 
 	gedit_debug (DEBUG_COMMANDS);
 
@@ -569,15 +691,36 @@ save_dialog_response_cb (GeditFileChooserDialog *dialog,
 	file = gtk_file_chooser_get_file (GTK_FILE_CHOOSER (dialog));
 	g_return_if_fail (file != NULL);
 
-	encoding = gedit_file_chooser_dialog_get_encoding (dialog);
-	newline_type = gedit_file_chooser_dialog_get_newline_type (dialog);
-
-	gtk_widget_destroy (GTK_WIDGET (dialog));
-
 	if (tab != NULL)
 	{
 		GeditDocument *doc;
 		gchar *parse_name;
+		GeditDocumentNewlineType newline_type;
+		GeditDocumentCompressionType compression_type;
+		GeditDocumentCompressionType current_compression_type;
+		const GeditEncoding *encoding;
+
+		doc = gedit_tab_get_document (tab);
+		compression_type = get_compression_type_from_file (file);
+		current_compression_type = gedit_document_get_compression_type (doc);
+
+		if ((compression_type == GEDIT_DOCUMENT_COMPRESSION_TYPE_NONE) !=
+		    (current_compression_type == GEDIT_DOCUMENT_COMPRESSION_TYPE_NONE))
+		{
+			if (!change_compression (GTK_WINDOW (dialog),
+			                         file,
+			                         compression_type != GEDIT_DOCUMENT_COMPRESSION_TYPE_NONE))
+			{
+				gtk_widget_destroy (GTK_WIDGET (dialog));
+
+				goto save_next_tab;
+			}
+		}
+
+		encoding = gedit_file_chooser_dialog_get_encoding (dialog);
+		newline_type = gedit_file_chooser_dialog_get_newline_type (dialog);
+
+		gtk_widget_destroy (GTK_WIDGET (dialog));
 
 		doc = gedit_tab_get_document (tab);
 		g_return_if_fail (GEDIT_IS_DOCUMENT (doc));
@@ -595,7 +738,7 @@ save_dialog_response_cb (GeditFileChooserDialog *dialog,
 		 * even if the saving fails... */
 		 _gedit_window_set_default_location (window, file);
 
-		_gedit_tab_save_as (tab, file, encoding, newline_type);
+		_gedit_tab_save_as (tab, file, encoding, newline_type, compression_type);
 	}
 
 	g_object_unref (file);
@@ -815,7 +958,7 @@ file_save (GeditTab    *tab,
 
 void
 _gedit_cmd_file_save (GtkAction   *action,
-		     GeditWindow *window)
+		      GeditWindow *window)
 {
 	GeditTab *tab;
 
@@ -830,7 +973,7 @@ _gedit_cmd_file_save (GtkAction   *action,
 
 void
 _gedit_cmd_file_save_as (GtkAction   *action,
-			GeditWindow *window)
+			 GeditWindow *window)
 {
 	GeditTab *tab;
 
@@ -984,7 +1127,7 @@ gedit_commands_save_all_documents (GeditWindow *window)
 
 void
 _gedit_cmd_file_save_all (GtkAction   *action,
-			 GeditWindow *window)
+			  GeditWindow *window)
 {
 	gedit_commands_save_all_documents (window);
 }
@@ -1172,7 +1315,7 @@ revert_dialog (GeditWindow   *window,
 
 void
 _gedit_cmd_file_revert (GtkAction   *action,
-		       GeditWindow *window)
+		        GeditWindow *window)
 {
 	GeditTab       *tab;
 	GeditDocument  *doc;
@@ -1185,9 +1328,11 @@ _gedit_cmd_file_revert (GtkAction   *action,
 	g_return_if_fail (tab != NULL);
 
 	/* If we are already displaying a notification
-	 * reverting will drop local modifications, do
+	 * reverting will drop local modifications or
+	 * if the document has not been modified, do
 	 * not bug the user further */
-	if (gedit_tab_get_state (tab) == GEDIT_TAB_STATE_EXTERNALLY_MODIFIED_NOTIFICATION)
+	if (gedit_tab_get_state (tab) == GEDIT_TAB_STATE_EXTERNALLY_MODIFIED_NOTIFICATION ||
+	    _gedit_tab_can_close (tab))
 	{
 		do_revert (window, tab);
 		return;
@@ -1544,7 +1689,9 @@ close_confirmation_dialog_response_handler (GeditCloseConfirmationDialog *dlg,
 					return;
 				}
 				else
+				{
 					g_return_if_reached ();
+				}
 			}
 			else
 			{
@@ -1587,6 +1734,7 @@ close_confirmation_dialog_response_handler (GeditCloseConfirmationDialog *dlg,
 			}
 
 			break;
+
 		default: /* Do not close */
 
 			/* Reset is_quitting flag */
@@ -1620,10 +1768,9 @@ tab_can_close (GeditTab  *tab,
 	{
 		GtkWidget     *dlg;
 
-		dlg = gedit_close_confirmation_dialog_new_single (
-						window,
-						doc,
-						FALSE);
+		dlg = gedit_close_confirmation_dialog_new_single (window,
+								  doc,
+								  FALSE);
 
 		g_signal_connect (dlg,
 				  "response",
@@ -1671,7 +1818,7 @@ _gedit_cmd_file_close_tab (GeditTab    *tab,
 
 void
 _gedit_cmd_file_close (GtkAction   *action,
-		      GeditWindow *window)
+		       GeditWindow *window)
 {
 	GeditTab *active_tab;
 
@@ -1764,7 +1911,7 @@ file_close_all (GeditWindow *window,
 
 void
 _gedit_cmd_file_close_all (GtkAction   *action,
-			  GeditWindow *window)
+			   GeditWindow *window)
 {
 	gedit_debug (DEBUG_COMMANDS);
 
@@ -1804,6 +1951,8 @@ quit_all ()
 			file_close_all (window, TRUE);
 		}
 	}
+
+	g_list_free (windows);
 }
 #endif
 
@@ -1828,4 +1977,5 @@ _gedit_cmd_file_quit (GtkAction   *action,
 
 	file_close_all (window, TRUE);
 }
+
 /* ex:ts=8:noet: */
