@@ -178,6 +178,11 @@ get_new_line_size (GeditDocumentInputStream *stream)
 		case GEDIT_DOCUMENT_NEWLINE_TYPE_CR_LF:
 			ret = 2;
 			break;
+
+		default:
+			g_warn_if_reached ();
+			ret = 1;
+			break;
 	}
 
 	return ret;
@@ -192,8 +197,8 @@ get_new_line_size (GeditDocumentInputStream *stream)
  * Returns: a new #GInputStream to read @buffer
  */
 GInputStream *
-gedit_document_input_stream_new (GtkTextBuffer           *buffer,
-				 GeditDocumentNewlineType type)
+gedit_document_input_stream_new (GtkTextBuffer            *buffer,
+				 GeditDocumentNewlineType  type)
 {
 	GeditDocumentInputStream *stream;
 
@@ -256,6 +261,11 @@ get_new_line (GeditDocumentInputStream *stream)
 		case GEDIT_DOCUMENT_NEWLINE_TYPE_CR_LF:
 			ret = "\r\n";
 			break;
+
+		default:
+			g_warn_if_reached ();
+			ret = "\n";
+			break;
 	}
 
 	return ret;
@@ -330,9 +340,19 @@ read_line (GeditDocumentInputStream *stream,
 
 		while (written < to_write)
 		{
+			gint w;
+
 			ptr = g_utf8_next_char (ptr);
-			written = (ptr - buf);
-			++char_offset;
+			w = (ptr - buf);
+			if (w > to_write)
+			{
+				break;
+			}
+			else
+			{
+				written = w;
+				++char_offset;
+			}
 		}
 
 		memcpy (outbuf, buf, written);
@@ -457,3 +477,5 @@ gedit_document_input_stream_close (GInputStream  *stream,
 
 	return TRUE;
 }
+
+/* ex:ts=8:noet: */
