@@ -41,12 +41,12 @@
 #include "gedit-document-loader.h"
 #include "gedit-document-output-stream.h"
 #include "gedit-smart-charset-converter.h"
-#include "gedit-prefs-manager.h"
 #include "gedit-debug.h"
 #include "gedit-metadata-manager.h"
 #include "gedit-utils.h"
 #include "gedit-marshal.h"
 #include "gedit-enum-types.h"
+#include "gedit-settings.h"
 
 #ifndef ENABLE_GVFS_METADATA
 #include "gedit-metadata-manager.h"
@@ -78,11 +78,13 @@ enum
 	PROP_DOCUMENT,
 	PROP_LOCATION,
 	PROP_ENCODING,
-	PROP_NEWLINE_TYPE
+	PROP_NEWLINE_TYPE,
+	PROP_STREAM,
+	PROP_COMPRESSION_TYPE
 };
 
 #define READ_CHUNK_SIZE 8192
-#define REMOTE_QUERY_ATTRIBUTES G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE "," \
+#define LOADER_QUERY_ATTRIBUTES G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE "," \
 				G_FILE_ATTRIBUTE_STANDARD_TYPE "," \
 				G_FILE_ATTRIBUTE_TIME_MODIFIED "," \
 				G_FILE_ATTRIBUTE_STANDARD_SIZE "," \
@@ -97,7 +99,10 @@ enum
 static void open_async_read (AsyncData *async);
 
 struct _GeditDocumentLoaderPrivate
-{	GeditDocument		 *document;
+{
+	GSettings		 *enc_settings;
+
+	GeditDocument		 *document;
 	gboolean		  used;
 
 	/* Info on the current file */
@@ -106,10 +111,10 @@ struct _GeditDocumentLoaderPrivate
 	const GeditEncoding	 *encoding;
 	const GeditEncoding	 *auto_detected_encoding;
 	GeditDocumentNewlineType  auto_detected_newline_type;
+	GeditDocumentCompressionType auto_detected_compression_type;
 	
 	goffset                   bytes_read;
 
-	/* Handle for remote files */
 	GCancellable 	         *cancellable;
 	GInputStream	         *stream;
 	GOutputStream            *output;
@@ -118,6 +123,7 @@ struct _GeditDocumentLoaderPrivate
 	gchar                     buffer[READ_CHUNK_SIZE];
 
 	GError                   *error;
+	gboolean                  guess_content_type_from_content;
 };
 
 G_DEFINE_TYPE(GeditDocumentLoader, gedit_document_loader, G_TYPE_OBJECT)
@@ -147,6 +153,12 @@ gedit_document_loader_set_property (GObject      *object,
 		case PROP_NEWLINE_TYPE:
 			loader->priv->auto_detected_newline_type = g_value_get_enum (value);
 			break;
+		case PROP_STREAM:
+			loader->priv->stream = g_value_dup_object (value);
+			break;
+		case PROP_COMPRESSION_TYPE:
+			loader->priv->auto_detected_compression_type = g_value_get_enum (value);
+			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 			break;
@@ -175,6 +187,12 @@ gedit_document_loader_get_property (GObject    *object,
 		case PROP_NEWLINE_TYPE:
 			g_value_set_enum (value, loader->priv->auto_detected_newline_type);
 			break;
+		case PROP_STREAM:
+			g_value_set_object (value, loader->priv->stream);
+			break;
+		case PROP_COMPRESSION_TYPE:
+			g_value_set_enum (value, loader->priv->auto_detected_compression_type);
+			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 			break;
@@ -230,6 +248,12 @@ gedit_document_loader_dispose (GObject *object)
 		g_object_unref (priv->location);
 		priv->location = NULL;
 	}
+	
+	if (priv->enc_settings != NULL)
+	{
+		g_object_unref (priv->enc_settings);
+		priv->enc_settings = NULL;
+	}
 
 	G_OBJECT_CLASS (gedit_document_loader_parent_class)->dispose (object);
 }
@@ -279,9 +303,30 @@ gedit_document_loader_class_init (GeditDocumentLoaderClass *klass)
 	                                                    GEDIT_TYPE_DOCUMENT_NEWLINE_TYPE,
 	                                                    GEDIT_DOCUMENT_NEWLINE_TYPE_LF,
 	                                                    G_PARAM_READWRITE |
+	                                                    G_PARAM_CONSTRUCT |
 	                                                    G_PARAM_STATIC_NAME |
 	                                                    G_PARAM_STATIC_BLURB));
 
+	g_object_class_install_property (object_class, PROP_COMPRESSION_TYPE,
+	                                 g_param_spec_enum ("compression-type",
+	                                                    "Compression type",
+	                                                    "The compression type",
+	                                                    GEDIT_TYPE_DOCUMENT_COMPRESSION_TYPE,
+	                                                    GEDIT_DOCUMENT_COMPRESSION_TYPE_NONE,
+	                                                    G_PARAM_READWRITE |
+	                                                    G_PARAM_CONSTRUCT |
+	                                                    G_PARAM_STATIC_NAME |
+	                                                    G_PARAM_STATIC_BLURB));
+
+	g_object_class_install_property (object_class,
+					 PROP_STREAM,
+					 g_param_spec_object ("stream",
+							      "STREAM",
+							      "The STREAM this GeditDocumentLoader loads the document from",
+							      G_TYPE_INPUT_STREAM,
+							      G_PARAM_READWRITE |
+							      G_PARAM_CONSTRUCT_ONLY));
+
 	signals[LOADING] =
 		g_signal_new ("loading",
 			      G_OBJECT_CLASS_TYPE (object_class),
@@ -302,10 +347,22 @@ gedit_document_loader_init (GeditDocumentLoader *loader)
 {
 	loader->priv = GEDIT_DOCUMENT_LOADER_GET_PRIVATE (loader);
 
-	loader->priv->used = FALSE;
-	loader->priv->auto_detected_newline_type = GEDIT_DOCUMENT_NEWLINE_TYPE_DEFAULT;
-	loader->priv->converter = NULL;
-	loader->priv->error = NULL;
+	loader->priv->enc_settings = g_settings_new ("org.gnome.gedit.preferences.encodings");
+}
+
+GeditDocumentLoader *
+gedit_document_loader_new_from_stream (GeditDocument       *doc,
+                                       GInputStream        *stream,
+                                       const GeditEncoding *encoding)
+{
+	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), NULL);
+	g_return_val_if_fail (G_IS_INPUT_STREAM (stream), NULL);
+
+	return GEDIT_DOCUMENT_LOADER (g_object_new (GEDIT_TYPE_DOCUMENT_LOADER,
+						    "document", doc,
+						    "stream", stream,
+						    "encoding", encoding,
+						    NULL));
 }
 
 GeditDocumentLoader *
@@ -331,7 +388,7 @@ async_data_new (GeditDocumentLoader *loader)
 	async->loader = loader;
 	async->cancellable = g_object_ref (loader->priv->cancellable);
 	async->tried_mount = FALSE;
-	
+
 	return async;
 }
 
@@ -347,14 +404,18 @@ get_metadata_encoding (GeditDocumentLoader *loader)
 {
 	const GeditEncoding *enc = NULL;
 
+	if (loader->priv->location == NULL)
+	{
+		/* If we are reading from a stream directly, then there is
+		   nothing to do */
+		return NULL;
+	}
+
 #ifndef ENABLE_GVFS_METADATA
 	gchar *charset;
-	GFile *location;
 	gchar *uri;
 
-	location = gedit_document_loader_get_location (loader);
-	uri = g_file_get_uri (location);
-	g_object_unref (location);
+	uri = g_file_get_uri (loader->priv->location);
 
 	charset = gedit_metadata_manager_get (uri, "encoding");
 	g_free (uri);
@@ -389,7 +450,8 @@ get_metadata_encoding (GeditDocumentLoader *loader)
 }
 
 static void
-remote_load_completed_or_failed (GeditDocumentLoader *loader, AsyncData *async)
+loader_load_completed_or_failed (GeditDocumentLoader *loader,
+				 AsyncData           *async)
 {
 	gedit_document_loader_loading (loader,
 				       TRUE,
@@ -400,16 +462,17 @@ remote_load_completed_or_failed (GeditDocumentLoader *loader, AsyncData *async)
 }
 
 static void
-async_failed (AsyncData *async, GError *error)
+async_failed (AsyncData *async,
+	      GError    *error)
 {
 	g_propagate_error (&async->loader->priv->error, error);
-	remote_load_completed_or_failed (async->loader, async);
+	loader_load_completed_or_failed (async->loader, async);
 }
 
 static void
 close_input_stream_ready_cb (GInputStream *stream,
-			     GAsyncResult  *res,
-			     AsyncData     *async)
+			     GAsyncResult *res,
+			     AsyncData    *async)
 {
 	GError *error = NULL;
 
@@ -440,18 +503,20 @@ close_input_stream_ready_cb (GInputStream *stream,
 		return;
 	}
 
-	remote_load_completed_or_failed (async->loader, async);
+	loader_load_completed_or_failed (async->loader, async);
 }
 
 static void
 write_complete (AsyncData *async)
 {
 	if (async->loader->priv->stream)
+	{
 		g_input_stream_close_async (G_INPUT_STREAM (async->loader->priv->stream),
 					    G_PRIORITY_HIGH,
 					    async->cancellable,
 					    (GAsyncReadyCallback)close_input_stream_ready_cb,
 					    async);
+	}
 }
 
 /* prototype, because they call each other... isn't C lovely */
@@ -532,6 +597,27 @@ async_read_cb (GInputStream *stream,
 		return;
 	}
 
+	if (loader->priv->guess_content_type_from_content &&
+	    async->read > 0 &&
+	    loader->priv->bytes_read == 0)
+	{
+		gchar *guessed;
+
+		guessed = g_content_type_guess (NULL,
+		                                (guchar *)loader->priv->buffer,
+		                                async->read,
+		                                NULL);
+
+		if (guessed != NULL)
+		{
+			g_file_info_set_attribute_string (loader->priv->info,
+			                                  G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE,
+			                                  guessed);
+
+			g_free (guessed);
+		}
+	}
+
 	/* Bump the size. */
 	loader->priv->bytes_read += async->read;
 
@@ -585,9 +671,16 @@ static GSList *
 get_candidate_encodings (GeditDocumentLoader *loader)
 {
 	const GeditEncoding *metadata;
-	GSList *encodings = NULL;
+	GSList *encodings;
+	gchar **enc_strv;
+	gsize len;
 
-	encodings = gedit_prefs_manager_get_auto_detected_encodings ();
+	enc_strv = g_settings_get_strv (loader->priv->enc_settings,
+					GEDIT_SETTINGS_ENCODING_AUTO_DETECTED,
+					&len);
+
+	encodings = _gedit_encoding_strv_to_list ((const gchar * const *)enc_strv);
+	g_strfreev (enc_strv);
 
 	metadata = get_metadata_encoding (loader);
 	if (metadata != NULL)
@@ -598,13 +691,86 @@ get_candidate_encodings (GeditDocumentLoader *loader)
 	return encodings;
 }
 
+static GInputStream *
+compression_gzip_stream (GeditDocumentLoader *loader)
+{
+	GZlibDecompressor *decompressor;
+	GInputStream *base_stream;
+
+	decompressor = g_zlib_decompressor_new (G_ZLIB_COMPRESSOR_FORMAT_GZIP);
+
+	base_stream = g_converter_input_stream_new (loader->priv->stream,
+	                                            G_CONVERTER (decompressor));
+
+	g_object_unref (decompressor);
+
+	loader->priv->auto_detected_compression_type = GEDIT_DOCUMENT_COMPRESSION_TYPE_GZIP;
+
+	return base_stream;
+}
+
+static void
+start_stream_read (AsyncData *async)
+{
+	GSList *candidate_encodings;
+	GeditDocumentLoader *loader;
+	GInputStream *base_stream = NULL;
+	GFileInfo *info;
+
+	loader = async->loader;
+	info = loader->priv->info;
+
+	/* Get the candidate encodings */
+	if (loader->priv->encoding == NULL)
+	{
+		candidate_encodings = get_candidate_encodings (loader);
+	}
+	else
+	{
+		candidate_encodings = g_slist_prepend (NULL, (gpointer)loader->priv->encoding);
+	}
+
+	loader->priv->converter = gedit_smart_charset_converter_new (candidate_encodings);
+	g_slist_free (candidate_encodings);
+
+	if (g_file_info_has_attribute (info, G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE))
+	{
+		const gchar *content_type = g_file_info_get_content_type (info);
+
+		switch (gedit_utils_get_compression_type_from_content_type (content_type))
+		{
+			case GEDIT_DOCUMENT_COMPRESSION_TYPE_GZIP:
+				base_stream = compression_gzip_stream (loader);
+				break;
+			case GEDIT_DOCUMENT_COMPRESSION_TYPE_NONE:
+				/* NOOP */
+				break;
+		}
+	}
+
+	if (base_stream == NULL)
+	{
+		base_stream = g_object_ref (loader->priv->stream);
+		loader->priv->auto_detected_compression_type = GEDIT_DOCUMENT_COMPRESSION_TYPE_NONE;
+	}
+
+	g_object_unref (loader->priv->stream);
+	loader->priv->stream = g_converter_input_stream_new (base_stream,
+	                                                     G_CONVERTER (loader->priv->converter));
+	g_object_unref (base_stream);
+
+	/* Output stream */
+	loader->priv->output = gedit_document_output_stream_new (loader->priv->document);
+
+	/* start reading */
+	read_file_chunk (async);
+}
+
 static void
 finish_query_info (AsyncData *async)
 {
 	GeditDocumentLoader *loader;
-	GInputStream *conv_stream;
 	GFileInfo *info;
-	GSList *candidate_encodings;
 	
 	loader = async->loader;
 	info = loader->priv->info;
@@ -618,35 +784,12 @@ finish_query_info (AsyncData *async)
 			     G_IO_ERROR_NOT_REGULAR_FILE,
 			     "Not a regular file");
 
-		remote_load_completed_or_failed (loader, async);
+		loader_load_completed_or_failed (loader, async);
 
 		return;
 	}
 
-	/* Get the candidate encodings */
-	if (loader->priv->encoding == NULL)
-	{
-		candidate_encodings = get_candidate_encodings (loader);
-	}
-	else
-	{
-		candidate_encodings = g_slist_prepend (NULL, (gpointer) loader->priv->encoding);
-	}
-
-	loader->priv->converter = gedit_smart_charset_converter_new (candidate_encodings);
-	g_slist_free (candidate_encodings);
-	
-	conv_stream = g_converter_input_stream_new (loader->priv->stream,
-						    G_CONVERTER (loader->priv->converter));
-	g_object_unref (loader->priv->stream);
-
-	loader->priv->stream = conv_stream;
-
-	/* Output stream */
-	loader->priv->output = gedit_document_output_stream_new (loader->priv->document);
-
-	/* start reading */
-	read_file_chunk (async);
+	start_stream_read (async);
 }
 
 static void
@@ -656,6 +799,7 @@ query_info_cb (GFile        *source,
 {
 	GFileInfo *info;
 	GError *error = NULL;
+	GeditDocumentLoaderPrivate *priv;
 
 	gedit_debug (DEBUG_LOADER);
 
@@ -666,8 +810,10 @@ query_info_cb (GFile        *source,
 		return;
 	}	
 
+	priv = async->loader->priv;
+
 	/* finish the info query */
-	info = g_file_query_info_finish (async->loader->priv->location,
+	info = g_file_query_info_finish (priv->location,
 	                                 res,
 	                                 &error);
 
@@ -678,8 +824,8 @@ query_info_cb (GFile        *source,
 		return;
 	}
 
-	async->loader->priv->info = info;
-	
+	priv->info = info;
+
 	finish_query_info (async);
 }
 
@@ -783,7 +929,7 @@ async_read_ready_callback (GObject      *source,
 	 * loading this is not too bad...
 	 */
 	g_file_query_info_async (loader->priv->location,
-				 REMOTE_QUERY_ATTRIBUTES,
+				 LOADER_QUERY_ATTRIBUTES,
                                  G_FILE_QUERY_INFO_NONE,
 				 G_PRIORITY_HIGH,
 				 async->cancellable,
@@ -850,8 +996,18 @@ gedit_document_loader_load (GeditDocumentLoader *loader)
 
 	loader->priv->cancellable = g_cancellable_new ();
 	async = async_data_new (loader);
-	
-	open_async_read (async);
+
+	if (loader->priv->stream)
+	{
+		loader->priv->guess_content_type_from_content = TRUE;
+		loader->priv->info = g_file_info_new ();
+
+		start_stream_read (async);
+	}
+	else
+	{
+		open_async_read (async);
+	}
 }
 
 gboolean
@@ -871,7 +1027,7 @@ gedit_document_loader_cancel (GeditDocumentLoader *loader)
 		     G_IO_ERROR_CANCELLED,
 		     "Operation cancelled");
 
-	remote_load_completed_or_failed (loader, NULL);
+	loader_load_completed_or_failed (loader, NULL);
 
 	return TRUE;
 }
@@ -884,13 +1040,19 @@ gedit_document_loader_get_document (GeditDocumentLoader *loader)
 	return loader->priv->document;
 }
 
-/* Returns STDIN_URI if loading from stdin */
 GFile *
 gedit_document_loader_get_location (GeditDocumentLoader *loader)
 {
 	g_return_val_if_fail (GEDIT_IS_DOCUMENT_LOADER (loader), NULL);
 
-	return g_file_dup (loader->priv->location);
+	if (loader->priv->location)
+	{
+		return g_file_dup (loader->priv->location);
+	}
+	else
+	{
+		return NULL;
+	}
 }
 
 goffset
@@ -924,6 +1086,15 @@ gedit_document_loader_get_newline_type (GeditDocumentLoader *loader)
 	return loader->priv->auto_detected_newline_type;
 }
 
+GeditDocumentCompressionType
+gedit_document_loader_get_compression_type (GeditDocumentLoader *loader)
+{
+	g_return_val_if_fail (GEDIT_IS_DOCUMENT_LOADER (loader),
+			      GEDIT_DOCUMENT_COMPRESSION_TYPE_NONE);
+
+	return loader->priv->auto_detected_compression_type;
+}
+
 GFileInfo *
 gedit_document_loader_get_info (GeditDocumentLoader *loader)
 {
@@ -931,4 +1102,5 @@ gedit_document_loader_get_info (GeditDocumentLoader *loader)
 
 	return loader->priv->info;
 }
+
 /* ex:ts=8:noet: */
