@@ -40,7 +40,7 @@
 #include <glib/gi18n.h>
 #include <gtksourceview/gtksourceiter.h>
 
-#include "gedit-prefs-manager-app.h"
+#include "gedit-settings.h"
 #include "gedit-document.h"
 #include "gedit-debug.h"
 #include "gedit-utils.h"
@@ -78,32 +78,36 @@ PROFILE (static GTimer *timer = NULL)
 
 #define GEDIT_DOCUMENT_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), GEDIT_TYPE_DOCUMENT, GeditDocumentPrivate))
 
-static void	gedit_document_load_real	(GeditDocument          *doc,
-						 GFile                  *location,
-						 const GeditEncoding    *encoding,
-						 gint                    line_pos,
-						 gint                    column_pos,
-						 gboolean                create);
-static void	gedit_document_save_real	(GeditDocument           *doc,
-						 GFile                   *location,
-						 const GeditEncoding     *encoding,
-						 GeditDocumentNewlineType newline_type,
-						 GeditDocumentSaveFlags   flags);
-static void	to_search_region_range 		(GeditDocument *doc,
-						 GtkTextIter   *start, 
-						 GtkTextIter   *end);
-static void 	insert_text_cb		 	(GeditDocument *doc, 
-						 GtkTextIter   *pos,
-						 const gchar   *text, 
-						 gint           length);
+static void	gedit_document_load_real	(GeditDocument                *doc,
+						 GFile                        *location,
+						 const GeditEncoding          *encoding,
+						 gint                          line_pos,
+						 gint                          column_pos,
+						 gboolean                      create);
+static void	gedit_document_save_real	(GeditDocument                *doc,
+						 GFile                        *location,
+						 const GeditEncoding          *encoding,
+						 GeditDocumentNewlineType      newline_type,
+						 GeditDocumentCompressionType  compression_type,
+						 GeditDocumentSaveFlags        flags);
+static void	to_search_region_range 		(GeditDocument                *doc,
+						 GtkTextIter                  *start,
+						 GtkTextIter                  *end);
+static void 	insert_text_cb		 	(GeditDocument                *doc,
+						 GtkTextIter                  *pos,
+						 const gchar                  *text,
+						 gint                          length);
 						 
-static void	delete_range_cb 		(GeditDocument *doc, 
-						 GtkTextIter   *start,
-						 GtkTextIter   *end);
+static void	delete_range_cb 		(GeditDocument                *doc,
+						 GtkTextIter                  *start,
+						 GtkTextIter                  *end);
 			     
 struct _GeditDocumentPrivate
 {
+	GSettings   *editor_settings;
+
 	GFile       *location;
+
 	gint 	     untitled_number;
 	gchar       *short_name;
 
@@ -121,6 +125,7 @@ struct _GeditDocumentPrivate
 	gint	     num_of_lines_search_text;
 
 	GeditDocumentNewlineType newline_type;
+	GeditDocumentCompressionType compression_type;
 
 	/* Temp data while loading */
 	GeditDocumentLoader *loader;
@@ -159,7 +164,8 @@ enum {
 	PROP_ENCODING,
 	PROP_CAN_SEARCH_AGAIN,
 	PROP_ENABLE_SEARCH_HIGHLIGHTING,
-	PROP_NEWLINE_TYPE
+	PROP_NEWLINE_TYPE,
+	PROP_COMPRESSION_TYPE
 };
 
 enum {
@@ -236,6 +242,18 @@ set_newline_type (GeditDocument           *doc,
 	}
 }
 
+static void
+set_compression_type (GeditDocument *doc,
+                      GeditDocumentCompressionType compression_type)
+{
+	if (doc->priv->compression_type != compression_type)
+	{
+		doc->priv->compression_type = compression_type;
+
+		g_object_notify (G_OBJECT (doc), "compression-type");
+	}
+}
+
 static void
 gedit_document_dispose (GObject *object)
 {
@@ -274,12 +292,17 @@ gedit_document_dispose (GObject *object)
 					    gtk_text_iter_get_offset (&iter));
 
 		if (language == NULL)
+		{
 			gedit_document_set_metadata (doc, GEDIT_METADATA_ATTRIBUTE_POSITION,
 						     position, NULL);
+		}
 		else
+		{
 			gedit_document_set_metadata (doc, GEDIT_METADATA_ATTRIBUTE_POSITION,
 						     position, GEDIT_METADATA_ATTRIBUTE_LANGUAGE,
 						     language, NULL);
+		}
+
 		g_free (position);
 	}
 
@@ -288,6 +311,12 @@ gedit_document_dispose (GObject *object)
 		g_object_unref (doc->priv->loader);
 		doc->priv->loader = NULL;
 	}
+	
+	if (doc->priv->editor_settings)
+	{
+		g_object_unref (doc->priv->editor_settings);
+		doc->priv->editor_settings = NULL;
+	}
 
 	if (doc->priv->metadata_info != NULL)
 	{
@@ -367,6 +396,9 @@ gedit_document_get_property (GObject    *object,
 		case PROP_NEWLINE_TYPE:
 			g_value_set_enum (value, doc->priv->newline_type);
 			break;
+		case PROP_COMPRESSION_TYPE:
+			g_value_set_enum (value, doc->priv->compression_type);
+			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 			break;
@@ -391,6 +423,10 @@ gedit_document_set_property (GObject      *object,
 			set_newline_type (doc,
 					  g_value_get_enum (value));
 			break;
+		case PROP_COMPRESSION_TYPE:
+			set_compression_type (doc,
+			                      g_value_get_enum (value));
+			break;
 		case PROP_SHORTNAME:
 			gedit_document_set_short_name_for_display (doc,
 			                                           g_value_get_string (value));
@@ -424,9 +460,11 @@ gedit_document_mark_set (GtkTextBuffer     *buffer,
 	GeditDocument *doc = GEDIT_DOCUMENT (buffer);
 
 	if (GTK_TEXT_BUFFER_CLASS (gedit_document_parent_class)->mark_set)
+	{
 		GTK_TEXT_BUFFER_CLASS (gedit_document_parent_class)->mark_set (buffer,
 									       iter,
 									       mark);
+	}
 
 	if (mark == gtk_text_buffer_get_insert (buffer))
 	{
@@ -536,6 +574,24 @@ gedit_document_class_init (GeditDocumentClass *klass)
 	                                                    GEDIT_TYPE_DOCUMENT_NEWLINE_TYPE,
 	                                                    GEDIT_DOCUMENT_NEWLINE_TYPE_LF,
 	                                                    G_PARAM_READWRITE |
+	                                                    G_PARAM_CONSTRUCT |
+	                                                    G_PARAM_STATIC_NAME |
+	                                                    G_PARAM_STATIC_BLURB));
+
+	/**
+	 * GeditDocument:compression-type:
+	 *
+	 * The :compression-type property determines how to compress the
+	 * document when saving
+	 */
+	g_object_class_install_property (object_class, PROP_COMPRESSION_TYPE,
+	                                 g_param_spec_enum ("compression-type",
+	                                                    "Compression type",
+	                                                    "The save compression type",
+	                                                    GEDIT_TYPE_DOCUMENT_COMPRESSION_TYPE,
+	                                                    GEDIT_DOCUMENT_COMPRESSION_TYPE_NONE,
+	                                                    G_PARAM_READWRITE |
+	                                                    G_PARAM_CONSTRUCT |
 	                                                    G_PARAM_STATIC_NAME |
 	                                                    G_PARAM_STATIC_BLURB));
 
@@ -624,14 +680,15 @@ gedit_document_class_init (GeditDocumentClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GeditDocumentClass, save),
 			      NULL, NULL,
-			      gedit_marshal_VOID__OBJECT_BOXED_ENUM_FLAGS,
+			      gedit_marshal_VOID__OBJECT_BOXED_ENUM_ENUM_FLAGS,
 			      G_TYPE_NONE,
-			      4,
+			      5,
 			      G_TYPE_FILE,
 			      /* we rely on the fact that the GeditEncoding pointer stays
 			       * the same forever */
 			      GEDIT_TYPE_ENCODING | G_SIGNAL_TYPE_STATIC_SCOPE,
 			      GEDIT_TYPE_DOCUMENT_NEWLINE_TYPE,
+			      GEDIT_TYPE_DOCUMENT_COMPRESSION_TYPE,
 			      GEDIT_TYPE_DOCUMENT_SAVE_FLAGS);
 
 	document_signals[SAVING] =
@@ -689,11 +746,20 @@ set_language (GeditDocument     *doc,
 	gtk_source_buffer_set_language (GTK_SOURCE_BUFFER (doc), lang);
 
 	if (lang != NULL)
+	{
+		gboolean syntax_hl;
+		
+		syntax_hl = g_settings_get_boolean (doc->priv->editor_settings,
+						    GEDIT_SETTINGS_SYNTAX_HIGHLIGHTING);
+		
 		gtk_source_buffer_set_highlight_syntax (GTK_SOURCE_BUFFER (doc),
-				 gedit_prefs_manager_get_enable_syntax_highlighting ());
+							syntax_hl);
+	}
 	else
-		gtk_source_buffer_set_highlight_syntax (GTK_SOURCE_BUFFER (doc), 
-				 FALSE);
+	{
+		gtk_source_buffer_set_highlight_syntax (GTK_SOURCE_BUFFER (doc),
+							FALSE);
+	}
 
 	if (set_by_user)
 	{
@@ -733,14 +799,14 @@ set_encoding (GeditDocument       *doc,
 }
 
 static GtkSourceStyleScheme *
-get_default_style_scheme (void)
+get_default_style_scheme (GSettings *editor_settings)
 {
 	gchar *scheme_id;
 	GtkSourceStyleScheme *def_style;
 	GtkSourceStyleSchemeManager *manager;
 
 	manager = gedit_get_style_scheme_manager ();
-	scheme_id = gedit_prefs_manager_get_source_style_scheme ();
+	scheme_id = g_settings_get_string (editor_settings, GEDIT_SETTINGS_SCHEME);
 	def_style = gtk_source_style_scheme_manager_get_scheme (manager,
 								scheme_id);
 
@@ -887,10 +953,15 @@ static void
 gedit_document_init (GeditDocument *doc)
 {
 	GtkSourceStyleScheme *style_scheme;
+	gint undo_actions;
+	gboolean bracket_matching;
+	gboolean search_hl;
 
 	gedit_debug (DEBUG_DOCUMENT);
 
 	doc->priv = GEDIT_DOCUMENT_GET_PRIVATE (doc);
+	
+	doc->priv->editor_settings = g_settings_new ("org.gnome.gedit.preferences.editor");
 
 	doc->priv->location = NULL;
 	doc->priv->untitled_number = get_untitled_number ();
@@ -915,18 +986,23 @@ gedit_document_init (GeditDocument *doc)
 
 	doc->priv->encoding = gedit_encoding_get_utf8 ();
 
-	doc->priv->newline_type = GEDIT_DOCUMENT_NEWLINE_TYPE_DEFAULT;
+	g_settings_get (doc->priv->editor_settings, GEDIT_SETTINGS_MAX_UNDO_ACTIONS,
+			"u", &undo_actions);
+	bracket_matching = g_settings_get_boolean (doc->priv->editor_settings,
+						   GEDIT_SETTINGS_BRACKET_MATCHING);
+	search_hl = g_settings_get_boolean (doc->priv->editor_settings,
+					    GEDIT_SETTINGS_SEARCH_HIGHLIGHTING);
 
 	gtk_source_buffer_set_max_undo_levels (GTK_SOURCE_BUFFER (doc), 
-					       gedit_prefs_manager_get_undo_actions_limit ());
+					       undo_actions);
 
 	gtk_source_buffer_set_highlight_matching_brackets (GTK_SOURCE_BUFFER (doc), 
-							   gedit_prefs_manager_get_bracket_matching ());
+							   bracket_matching);
 
 	gedit_document_set_enable_search_highlighting (doc,
-						       gedit_prefs_manager_get_enable_search_highlighting ());
+						       search_hl);
 
-	style_scheme = get_default_style_scheme ();
+	style_scheme = get_default_style_scheme (doc->priv->editor_settings);
 	if (style_scheme != NULL)
 		gtk_source_buffer_set_style_scheme (GTK_SOURCE_BUFFER (doc),
 						    style_scheme);
@@ -960,22 +1036,71 @@ gedit_document_new (void)
 	return GEDIT_DOCUMENT (g_object_new (GEDIT_TYPE_DOCUMENT, NULL));
 }
 
+static gchar *
+get_content_type_from_content (GeditDocument *doc)
+{
+	gchar *content_type;
+	gchar *data;
+	gsize datalen;
+	GtkTextBuffer *buf;
+	GtkTextIter start, end;
+
+	buf = GTK_TEXT_BUFFER (doc);
+
+	gtk_text_buffer_get_start_iter (buf, &start);
+	end = start;
+	gtk_text_iter_forward_chars (&end, 255);
+
+	data = gtk_text_buffer_get_text (buf, &start, &end, TRUE);
+	datalen = strlen (data);
+
+	content_type = g_content_type_guess (NULL,
+	                                     (const guchar *)data,
+	                                     datalen,
+	                                     NULL);
+
+	g_free (data);
+
+	return content_type;
+}
+
 static void
 set_content_type_no_guess (GeditDocument *doc,
 			   const gchar   *content_type)
 {
+	gchar *dupped_content_type;
+
 	gedit_debug (DEBUG_DOCUMENT);
 
 	if (doc->priv->content_type != NULL && content_type != NULL &&
 	    (0 == strcmp (doc->priv->content_type, content_type)))
+	{
 		return;
+	}
 
 	g_free (doc->priv->content_type);
 
-	if (content_type == NULL || g_content_type_is_unknown (content_type))
-		doc->priv->content_type = get_default_content_type ();
+	/* For compression types, we try to just guess from the content */
+	if (gedit_utils_get_compression_type_from_content_type (content_type) !=
+	    GEDIT_DOCUMENT_COMPRESSION_TYPE_NONE)
+	{
+		dupped_content_type = get_content_type_from_content (doc);
+	}
 	else
-		doc->priv->content_type = g_strdup (content_type);
+	{
+		dupped_content_type = g_strdup (content_type);
+	}
+
+	if (dupped_content_type == NULL ||
+	    g_content_type_is_unknown (dupped_content_type))
+	{
+		doc->priv->content_type = get_default_content_type ();
+		g_free (dupped_content_type);
+	}
+	else
+	{
+		doc->priv->content_type = dupped_content_type;
+	}
 
 	g_object_notify (G_OBJECT (doc), "content-type");
 }
@@ -1031,13 +1156,17 @@ set_location (GeditDocument *doc,
 
 	g_return_if_fail ((location == NULL) || gedit_utils_is_valid_location (location));
 
+	if (doc->priv->location == location)
+		return;
+
+	if (doc->priv->location != NULL)
+	{
+		g_object_unref (doc->priv->location);
+		doc->priv->location = NULL;
+	}
+
 	if (location != NULL)
 	{
-		if (doc->priv->location == location)
-			return;
-
-		if (doc->priv->location != NULL)
-			g_object_unref (doc->priv->location);
 		doc->priv->location = g_file_dup (location);
 
 		if (doc->priv->untitled_number > 0)
@@ -1081,10 +1210,14 @@ gedit_document_get_uri_for_display (GeditDocument *doc)
 	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), g_strdup (""));
 
 	if (doc->priv->location == NULL)
+	{
 		return g_strdup_printf (_("Unsaved Document %d"),
 					doc->priv->untitled_number);
+	}
 	else
+	{
 		return gedit_utils_uri_for_display (doc->priv->location);
+	}
 }
 
 /* Never returns NULL */
@@ -1094,12 +1227,18 @@ gedit_document_get_short_name_for_display (GeditDocument *doc)
 	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), g_strdup (""));
 
 	if (doc->priv->short_name != NULL)
+	{
 		return g_strdup (doc->priv->short_name);
+	}
 	else if (doc->priv->location == NULL)
+	{
 		return g_strdup_printf (_("Unsaved Document %d"),
 					doc->priv->untitled_number);
+	}
 	else
+	{
 		return gedit_utils_basename_for_display (doc->priv->location);
+	}
 }
 
 void
@@ -1256,6 +1395,7 @@ document_loader_loaded (GeditDocumentLoader *loader,
 	{
 		GtkTextIter iter;
 		GFileInfo *info;
+		gboolean restore_cursor;
 		const gchar *content_type = NULL;
 		gboolean read_only = FALSE;
 		GTimeVal mtime = {0, 0};
@@ -1265,15 +1405,19 @@ document_loader_loaded (GeditDocumentLoader *loader,
 		if (info)
 		{
 			if (g_file_info_has_attribute (info, G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE))
+			{
 				content_type = g_file_info_get_attribute_string (info,
 										 G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE);
+			}
 
 			if (g_file_info_has_attribute (info, G_FILE_ATTRIBUTE_TIME_MODIFIED))
 				g_file_info_get_modification_time (info, &mtime);
 
 			if (g_file_info_has_attribute (info, G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE))
+			{
 				read_only = !g_file_info_get_attribute_boolean (info,
 										G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE);
+			}
 		}
 
 		doc->priv->mtime = mtime;
@@ -1291,6 +1435,12 @@ document_loader_loaded (GeditDocumentLoader *loader,
 		set_newline_type (doc,
 		                  gedit_document_loader_get_newline_type (loader));
 
+		set_compression_type (doc,
+		                      gedit_document_loader_get_compression_type (loader));
+
+		restore_cursor = g_settings_get_boolean (doc->priv->editor_settings,
+							 GEDIT_SETTINGS_RESTORE_CURSOR_POSITION);
+
 		/* move the cursor at the requested line if any */
 		if (doc->priv->requested_line_pos > 0)
 		{
@@ -1305,7 +1455,7 @@ document_loader_loaded (GeditDocumentLoader *loader,
 								 column);
 		}
 		/* else, if enabled, to the position stored in the metadata */
-		else if (gedit_prefs_manager_get_restore_cursor_position ())
+		else if (restore_cursor)
 		{
 			gchar *pos;
 			gint offset;
@@ -1380,8 +1530,10 @@ document_loader_loading (GeditDocumentLoader *loader,
 		info = gedit_document_loader_get_info (loader);
 
 		if (info && g_file_info_has_attribute (info, G_FILE_ATTRIBUTE_STANDARD_SIZE))
+		{
 			size = g_file_info_get_attribute_uint64 (info,
 								 G_FILE_ATTRIBUTE_STANDARD_SIZE);
+		}
 
 		read = gedit_document_loader_get_bytes_read (loader);
 
@@ -1428,6 +1580,38 @@ gedit_document_load_real (GeditDocument       *doc,
 	gedit_document_loader_load (doc->priv->loader);
 }
 
+void
+gedit_document_load_stream (GeditDocument       *doc,
+                            GInputStream        *stream,
+                            const GeditEncoding *encoding,
+                            gint                 line_pos,
+                            gint                 column_pos)
+{
+	g_return_if_fail (GEDIT_IS_DOCUMENT (doc));
+	g_return_if_fail (G_IS_INPUT_STREAM (stream));
+	g_return_if_fail (doc->priv->loader == NULL);
+
+	gedit_debug_message (DEBUG_DOCUMENT, "load stream");
+
+	/* create a loader. It will be destroyed when loading is completed */
+	doc->priv->loader = gedit_document_loader_new_from_stream (doc, stream, encoding);
+
+	g_signal_connect (doc->priv->loader,
+			  "loading",
+			  G_CALLBACK (document_loader_loading),
+			  doc);
+
+	doc->priv->create = FALSE;
+	doc->priv->requested_encoding = encoding;
+	doc->priv->requested_line_pos = line_pos;
+	doc->priv->requested_column_pos = column_pos;
+
+	set_location (doc, NULL);
+	set_content_type (doc, NULL);
+
+	gedit_document_loader_load (doc->priv->loader);
+}
+
 /**
  * gedit_document_load:
  * @doc: the #GeditDocument.
@@ -1548,18 +1732,22 @@ document_saver_saving (GeditDocumentSaver *saver,
 }
 
 static void
-gedit_document_save_real (GeditDocument           *doc,
-			  GFile                   *location,
-			  const GeditEncoding     *encoding,
-			  GeditDocumentNewlineType newline_type,
-			  GeditDocumentSaveFlags   flags)
+gedit_document_save_real (GeditDocument                *doc,
+			  GFile                        *location,
+			  const GeditEncoding          *encoding,
+			  GeditDocumentNewlineType      newline_type,
+			  GeditDocumentCompressionType  compression_type,
+			  GeditDocumentSaveFlags        flags)
 {
 	g_return_if_fail (doc->priv->saver == NULL);
 
 	/* create a saver, it will be destroyed once saving is complete */
-	doc->priv->saver = gedit_document_saver_new (doc, location, encoding,
-						     newline_type,
-						     flags);
+	doc->priv->saver = gedit_document_saver_new (doc,
+	                                             location,
+	                                             encoding,
+	                                             newline_type,
+	                                             compression_type,
+	                                             flags);
 
 	g_signal_connect (doc->priv->saver,
 			  "saving",
@@ -1568,6 +1756,7 @@ gedit_document_save_real (GeditDocument           *doc,
 
 	doc->priv->requested_encoding = encoding;
 	doc->priv->newline_type = newline_type;
+	doc->priv->compression_type = compression_type;
 
 	gedit_document_saver_save (doc->priv->saver,
 				   &doc->priv->mtime);
@@ -1594,6 +1783,7 @@ gedit_document_save (GeditDocument          *doc,
 		       doc->priv->location,
 		       doc->priv->encoding,
 		       doc->priv->newline_type,
+		       doc->priv->compression_type,
 		       flags);
 }
 
@@ -1609,11 +1799,12 @@ gedit_document_save (GeditDocument          *doc,
  * to be emitted.
  */
 void
-gedit_document_save_as (GeditDocument           *doc,
-			GFile                   *location,
-			const GeditEncoding     *encoding,
-			GeditDocumentNewlineType newline_type,
-			GeditDocumentSaveFlags   flags)
+gedit_document_save_as (GeditDocument                *doc,
+			GFile                        *location,
+			const GeditEncoding          *encoding,
+			GeditDocumentNewlineType      newline_type,
+			GeditDocumentCompressionType  compression_type,
+			GeditDocumentSaveFlags        flags)
 {
 	g_return_if_fail (GEDIT_IS_DOCUMENT (doc));
 	g_return_if_fail (G_IS_FILE (location));
@@ -1627,6 +1818,7 @@ gedit_document_save_as (GeditDocument           *doc,
 		       location,
 		       encoding,
 		       newline_type,
+		       compression_type,
 		       flags | GEDIT_DOCUMENT_SAVE_IGNORE_MTIME);
 }
 
@@ -1875,7 +2067,9 @@ gedit_document_search_forward (GeditDocument     *doc,
 		return FALSE;
 	}
 	else
+	{
 		gedit_debug_message (DEBUG_DOCUMENT, "doc->priv->search_text == \"%s\"\n", doc->priv->search_text);
+	}
 				      
 	if (start == NULL)
 		gtk_text_buffer_get_start_iter (GTK_TEXT_BUFFER (doc), &iter);
@@ -1907,7 +2101,9 @@ gedit_document_search_forward (GeditDocument     *doc,
 				iter = m_end;
 		}
 		else
+		{
 			break;
+		}
 	}
 	
 	if (found && (match_start != NULL))
@@ -1944,7 +2140,9 @@ gedit_document_search_backward (GeditDocument     *doc,
 		return FALSE;
 	}
 	else
+	{
 		gedit_debug_message (DEBUG_DOCUMENT, "doc->priv->search_text == \"%s\"\n", doc->priv->search_text);
+	}
 				      
 	if (end == NULL)
 		gtk_text_buffer_get_end_iter (GTK_TEXT_BUFFER (doc), &iter);
@@ -1976,7 +2174,9 @@ gedit_document_search_backward (GeditDocument     *doc,
 				iter = m_start;
 		}
 		else
+		{
 			break;
+		}
 	}
 	
 	if (found && (match_start != NULL))
@@ -2083,7 +2283,7 @@ gedit_document_replace_all (GeditDocument       *doc,
 						replace_text_len);
 
 			iter = m_start;
-		}		
+		}
 
 	} while (found);
 
@@ -2174,8 +2374,7 @@ get_search_match_colors (GeditDocument *doc,
 
 	if (*foreground_set)
 	{
-		if (fg == NULL ||
-		    !gdk_color_parse (fg, foreground))
+		if (fg == NULL || !gdk_color_parse (fg, foreground))
 		{
 			*foreground_set = FALSE;
 		}
@@ -2292,11 +2491,15 @@ search_region (GeditDocument *doc,
 
 	if (gtk_text_iter_has_tag (start, doc->priv->found_tag) &&
 	    !gtk_text_iter_begins_tag (start, doc->priv->found_tag))
+	{
 		gtk_text_iter_backward_to_tag_toggle (start, doc->priv->found_tag);
+	}
 
 	if (gtk_text_iter_has_tag (end, doc->priv->found_tag) &&
 	    !gtk_text_iter_ends_tag (end, doc->priv->found_tag))
+	{
 		gtk_text_iter_forward_to_tag_toggle (end, doc->priv->found_tag);
+	}
 
 	/*
 	g_print ("[%u (%u), %u (%u)]\n", gtk_text_iter_get_line (start), gtk_text_iter_get_offset (start),
@@ -2351,7 +2554,7 @@ search_region (GeditDocument *doc,
 						   doc->priv->found_tag,
 						   &m_start,
 						   &m_end);
-		}		
+		}
 
 	} while (found);
 }
@@ -2550,6 +2753,14 @@ gedit_document_get_newline_type (GeditDocument *doc)
 	return doc->priv->newline_type;
 }
 
+GeditDocumentCompressionType
+gedit_document_get_compression_type (GeditDocument *doc)
+{
+	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), 0);
+
+	return doc->priv->compression_type;
+}
+
 void
 _gedit_document_set_mount_operation_factory (GeditDocument 	       *doc,
 					    GeditMountOperationFactory	callback,
@@ -2567,10 +2778,14 @@ _gedit_document_create_mount_operation (GeditDocument *doc)
 	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), NULL);
 	
 	if (doc->priv->mount_operation_factory == NULL)
+	{
 		return g_mount_operation_new ();
+	}
 	else
-		return doc->priv->mount_operation_factory (doc, 
+	{
+		return doc->priv->mount_operation_factory (doc,
 						           doc->priv->mount_operation_userdata);
+	}
 }
 
 #ifndef ENABLE_GVFS_METADATA
@@ -2734,4 +2949,5 @@ gedit_document_set_metadata (GeditDocument *doc,
 	g_object_unref (info);
 }
 #endif
+
 /* ex:ts=8:noet: */
