@@ -37,8 +37,9 @@
 #include <gtk/gtk.h>
 
 #include <gedit/gedit-encodings-combo-box.h>
-#include <gedit/gedit-prefs-manager.h>
 #include <gedit/dialogs/gedit-encodings-dialog.h>
+#include "gedit-settings.h"
+#include "gedit-utils.h"
 
 #include "gseal-gtk-compat.h"
 
@@ -50,6 +51,8 @@
 
 struct _GeditEncodingsComboBoxPrivate
 {
+	GSettings *enc_settings;
+
 	GtkListStore *store;
 	glong changed_id;
 
@@ -234,7 +237,9 @@ add_or_remove (GeditEncodingsComboBox *menu,
 }
 
 static gboolean
-separator_func (GtkTreeModel *model, GtkTreeIter *iter, gpointer data)
+separator_func (GtkTreeModel *model,
+		GtkTreeIter  *iter,
+		gpointer      data)
 {
 	gchar *str;
 	gboolean ret;
@@ -255,6 +260,8 @@ update_menu (GeditEncodingsComboBox *menu)
 	gchar *str;
 	const GeditEncoding *utf8_encoding;
 	const GeditEncoding *current_encoding;
+	gchar **enc_strv;
+	gsize len;
 
 	store = menu->priv->store;
 
@@ -285,10 +292,14 @@ update_menu (GeditEncodingsComboBox *menu)
 	}
 
 	if (current_encoding != utf8_encoding)
+	{
 		str = gedit_encoding_to_string (utf8_encoding);
+	}
 	else
+	{
 		str = g_strdup_printf (_("Current Locale (%s)"),
 				       gedit_encoding_get_charset (utf8_encoding));
+	}
 
 	gtk_list_store_append (store, &iter);
 	gtk_list_store_set (store, &iter,
@@ -315,7 +326,12 @@ update_menu (GeditEncodingsComboBox *menu)
 		g_free (str);
 	}
 
-	encodings = gedit_prefs_manager_get_shown_in_menu_encodings ();
+	enc_strv = g_settings_get_strv (menu->priv->enc_settings,
+					GEDIT_SETTINGS_ENCODING_SHOWN_IN_MENU,
+					&len);
+
+	encodings = _gedit_encoding_strv_to_list ((const gchar * const *)enc_strv);
+	g_strfreev (enc_strv);
 
 	for (l = encodings; l != NULL; l = g_slist_next (l))
 	{
@@ -340,23 +356,20 @@ update_menu (GeditEncodingsComboBox *menu)
 
 	g_slist_free (encodings);
 
-	if (gedit_prefs_manager_shown_in_menu_encodings_can_set ())
-	{
-		gtk_list_store_append (store, &iter);
-		/* separator */
-		gtk_list_store_set (store, &iter,
-				    NAME_COLUMN, "",
-				    ENCODING_COLUMN, NULL,
-				    ADD_COLUMN, FALSE,
-				    -1);
+	gtk_list_store_append (store, &iter);
+	/* separator */
+	gtk_list_store_set (store, &iter,
+			    NAME_COLUMN, "",
+			    ENCODING_COLUMN, NULL,
+			    ADD_COLUMN, FALSE,
+			    -1);
 
-		gtk_list_store_append (store, &iter);
-		gtk_list_store_set (store, &iter,
-				    NAME_COLUMN, _("Add or Remove..."),
-				    ENCODING_COLUMN, NULL,
-				    ADD_COLUMN, TRUE,
-				    -1);
-	}
+	gtk_list_store_append (store, &iter);
+	gtk_list_store_set (store, &iter,
+			    NAME_COLUMN, _("Add or Remove..."),
+			    ENCODING_COLUMN, NULL,
+			    ADD_COLUMN, TRUE,
+			    -1);
 
 	/* set the model back */
 	gtk_combo_box_set_model (GTK_COMBO_BOX (menu),
@@ -373,6 +386,8 @@ gedit_encodings_combo_box_init (GeditEncodingsComboBox *menu)
 
 	menu->priv = GEDIT_ENCODINGS_COMBO_BOX_GET_PRIVATE (menu);
 
+	menu->priv->enc_settings = g_settings_new ("org.gnome.gedit.preferences.encodings");
+
 	menu->priv->store = gtk_list_store_new (N_COLUMNS,
 						G_TYPE_STRING,
 						G_TYPE_POINTER,
@@ -464,4 +479,5 @@ gedit_encodings_combo_box_set_selected_encoding (GeditEncodingsComboBox *menu,
 		b = gtk_tree_model_iter_next (model, &iter);
 	}
 }
+
 /* ex:ts=8:noet: */
