@@ -41,10 +41,11 @@
 #include <gtk/gtk.h>
 
 #include "gedit-file-chooser-dialog.h"
-#include "gedit-encodings-option-menu.h"
+#include "gedit-encodings-combo-box.h"
 #include "gedit-language-manager.h"
-#include "gedit-prefs-manager-app.h"
 #include "gedit-debug.h"
+#include "gedit-enum-types.h"
+#include "gedit-settings.h"
 
 #define GEDIT_FILE_CHOOSER_DIALOG_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), GEDIT_TYPE_FILE_CHOOSER_DIALOG, GeditFileChooserDialogPrivate))
 
@@ -53,52 +54,183 @@
 
 struct _GeditFileChooserDialogPrivate
 {
+	GSettings *filter_settings;
+
 	GtkWidget *option_menu;
+	GtkWidget *extra_widget;
+
+	GtkWidget *newline_label;
+	GtkWidget *newline_combo;
+	GtkListStore *newline_store;
 };
 
 G_DEFINE_TYPE(GeditFileChooserDialog, gedit_file_chooser_dialog, GTK_TYPE_FILE_CHOOSER_DIALOG)
 
+static void
+gedit_file_chooser_dialog_dispose (GObject *object)
+{
+	GeditFileChooserDialog *dialog = GEDIT_FILE_CHOOSER_DIALOG (object);
+
+	if (dialog->priv->filter_settings != NULL)
+	{
+		g_object_unref (dialog->priv->filter_settings);
+		dialog->priv->filter_settings = NULL;
+	}
+
+	G_OBJECT_CLASS (gedit_file_chooser_dialog_parent_class)->dispose (object);
+}
+
 static void
 gedit_file_chooser_dialog_class_init (GeditFileChooserDialogClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-	g_type_class_add_private (object_class, sizeof(GeditFileChooserDialogPrivate));
+	object_class->dispose = gedit_file_chooser_dialog_dispose;
+
+	g_type_class_add_private (object_class, sizeof (GeditFileChooserDialogPrivate));
 }
 
 static void
 create_option_menu (GeditFileChooserDialog *dialog)
 {
-	GtkWidget *hbox;
 	GtkWidget *label;
 	GtkWidget *menu;
 
-	hbox = gtk_hbox_new (FALSE, 6);
+	label = gtk_label_new_with_mnemonic (_("C_haracter Encoding:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
-	label = gtk_label_new_with_mnemonic (_("C_haracter Coding:"));
-	menu = gedit_encodings_option_menu_new (
+	menu = gedit_encodings_combo_box_new (
 		gtk_file_chooser_get_action (GTK_FILE_CHOOSER (dialog)) == GTK_FILE_CHOOSER_ACTION_SAVE);
 
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), menu);
-	gtk_box_pack_start (GTK_BOX (hbox),
-			    label,
-			    FALSE,
-			    FALSE,
-			    0);
 
-	gtk_box_pack_end (GTK_BOX (hbox),
-			  menu,
-			  TRUE,
-			  TRUE,
-			  0);
+	gtk_box_pack_start (GTK_BOX (dialog->priv->extra_widget),
+	                    label,
+	                    FALSE,
+	                    TRUE,
+	                    0);
 
-	gtk_file_chooser_set_extra_widget (GTK_FILE_CHOOSER (dialog),
-					   hbox);
-	gtk_widget_show_all (hbox);
+	gtk_box_pack_start (GTK_BOX (dialog->priv->extra_widget),
+	                    menu,
+	                    TRUE,
+	                    TRUE,
+	                    0);
+
+	gtk_widget_show (label);
+	gtk_widget_show (menu);
 
 	dialog->priv->option_menu = menu;
 }
 
+static void
+update_newline_visibility (GeditFileChooserDialog *dialog)
+{
+	if (gtk_file_chooser_get_action (GTK_FILE_CHOOSER (dialog)) == GTK_FILE_CHOOSER_ACTION_SAVE)
+	{
+		gtk_widget_show (dialog->priv->newline_label);
+		gtk_widget_show (dialog->priv->newline_combo);
+	}
+	else
+	{
+		gtk_widget_hide (dialog->priv->newline_label);
+		gtk_widget_hide (dialog->priv->newline_combo);
+	}
+}
+
+static void
+newline_combo_append (GtkComboBox              *combo,
+                      GtkListStore             *store,
+                      GtkTreeIter              *iter,
+                      const gchar              *label,
+                      GeditDocumentNewlineType  newline_type)
+{
+	gtk_list_store_append (store, iter);
+	gtk_list_store_set (store, iter, 0, label, 1, newline_type, -1);
+
+	if (newline_type == GEDIT_DOCUMENT_NEWLINE_TYPE_DEFAULT)
+	{
+		gtk_combo_box_set_active_iter (combo, iter);
+	}
+}
+
+static void
+create_newline_combo (GeditFileChooserDialog *dialog)
+{
+	GtkWidget *label, *combo;
+	GtkListStore *store;
+	GtkCellRenderer *renderer;
+	GtkTreeIter iter;
+
+	label = gtk_label_new_with_mnemonic (_("L_ine Ending:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+
+	store = gtk_list_store_new (2, G_TYPE_STRING, GEDIT_TYPE_DOCUMENT_NEWLINE_TYPE);
+	combo = gtk_combo_box_new_with_model (GTK_TREE_MODEL (store));
+	renderer = gtk_cell_renderer_text_new ();
+
+	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo),
+	                            renderer,
+	                            TRUE);
+
+	gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (combo),
+	                               renderer,
+	                               "text",
+	                               0);
+
+	newline_combo_append (GTK_COMBO_BOX (combo),
+	                      store,
+	                      &iter,
+	                      _("Unix/Linux"),
+	                      GEDIT_DOCUMENT_NEWLINE_TYPE_LF);
+
+	newline_combo_append (GTK_COMBO_BOX (combo),
+	                      store,
+	                      &iter,
+	                      _("Mac OS Classic"),
+	                      GEDIT_DOCUMENT_NEWLINE_TYPE_CR);
+
+	newline_combo_append (GTK_COMBO_BOX (combo),
+	                      store,
+	                      &iter,
+	                      _("Windows"),
+	                      GEDIT_DOCUMENT_NEWLINE_TYPE_CR_LF);
+
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), combo);
+
+	gtk_box_pack_start (GTK_BOX (dialog->priv->extra_widget),
+	                    label,
+	                    FALSE,
+	                    TRUE,
+	                    0);
+
+	gtk_box_pack_start (GTK_BOX (dialog->priv->extra_widget),
+	                    combo,
+	                    TRUE,
+	                    TRUE,
+	                    0);
+
+	dialog->priv->newline_combo = combo;
+	dialog->priv->newline_label = label;
+	dialog->priv->newline_store = store;
+
+	update_newline_visibility (dialog);
+}
+
+static void
+create_extra_widget (GeditFileChooserDialog *dialog)
+{
+	dialog->priv->extra_widget = gtk_hbox_new (FALSE, 6);
+
+	gtk_widget_show (dialog->priv->extra_widget);
+
+	create_option_menu (dialog);
+	create_newline_combo (dialog);
+
+	gtk_file_chooser_set_extra_widget (GTK_FILE_CHOOSER (dialog),
+					   dialog->priv->extra_widget);
+
+}
+
 static void
 action_changed (GeditFileChooserDialog *dialog,
 		GParamSpec	       *pspec,
@@ -125,6 +257,8 @@ action_changed (GeditFileChooserDialog *dialog,
 		default:
 			gtk_widget_hide (dialog->priv->option_menu);
 	}
+
+	update_newline_visibility (dialog);
 }
 
 static void
@@ -134,9 +268,6 @@ filter_changed (GeditFileChooserDialog *dialog,
 {
 	GtkFileFilter *filter;
 
-	if (!gedit_prefs_manager_active_file_filter_can_set ())
-		return;
-
 	filter = gtk_file_chooser_get_filter (GTK_FILE_CHOOSER (dialog));
 	if (filter != NULL)
 	{
@@ -151,7 +282,8 @@ filter_changed (GeditFileChooserDialog *dialog,
 
 		gedit_debug_message (DEBUG_COMMANDS, "Active filter: %s (%d)", name, id);
 
-		gedit_prefs_manager_set_active_file_filter (id);
+		g_settings_set_int (dialog->priv->filter_settings,
+				    GEDIT_SETTINGS_ACTIVE_FILE_FILTER, id);
 	}
 }
 
@@ -237,6 +369,8 @@ static void
 gedit_file_chooser_dialog_init (GeditFileChooserDialog *dialog)
 {
 	dialog->priv = GEDIT_FILE_CHOOSER_DIALOG_GET_PRIVATE (dialog);
+	
+	dialog->priv->filter_settings = g_settings_new ("org.gnome.gedit.state.file-filter");
 }
 
 static GtkWidget *
@@ -263,7 +397,7 @@ gedit_file_chooser_dialog_new_valist (const gchar          *title,
 			       "select-multiple", action == GTK_FILE_CHOOSER_ACTION_OPEN,
 			       NULL);
 
-	create_option_menu (GEDIT_FILE_CHOOSER_DIALOG (result));
+	create_extra_widget (GEDIT_FILE_CHOOSER_DIALOG (result));
 
 	g_signal_connect (result,
 			  "notify::action",
@@ -271,11 +405,14 @@ gedit_file_chooser_dialog_new_valist (const gchar          *title,
 			  NULL);
 
 	if (encoding != NULL)
-		gedit_encodings_option_menu_set_selected_encoding (
-				GEDIT_ENCODINGS_OPTION_MENU (GEDIT_FILE_CHOOSER_DIALOG (result)->priv->option_menu),
+	{
+		gedit_encodings_combo_box_set_selected_encoding (
+				GEDIT_ENCODINGS_COMBO_BOX (GEDIT_FILE_CHOOSER_DIALOG (result)->priv->option_menu),
 				encoding);
+	}
 
-	active_filter = gedit_prefs_manager_get_active_file_filter ();
+	active_filter = g_settings_get_int (GEDIT_FILE_CHOOSER_DIALOG (result)->priv->filter_settings,
+					    GEDIT_SETTINGS_ACTIVE_FILE_FILTER);
 	gedit_debug_message (DEBUG_COMMANDS, "Active filter: %d", active_filter);
 
 	/* Filters */
@@ -323,7 +460,9 @@ gedit_file_chooser_dialog_new_valist (const gchar          *title,
 		    (response_id == GTK_RESPONSE_ACCEPT) ||
 		    (response_id == GTK_RESPONSE_YES) ||
 		    (response_id == GTK_RESPONSE_APPLY))
+		{
 			gtk_dialog_set_default_response (GTK_DIALOG (result), response_id);
+		}
 
 		button_text = va_arg (varargs, const gchar *);
 	}
@@ -370,10 +509,10 @@ gedit_file_chooser_dialog_set_encoding (GeditFileChooserDialog *dialog,
 					const GeditEncoding    *encoding)
 {
 	g_return_if_fail (GEDIT_IS_FILE_CHOOSER_DIALOG (dialog));
-	g_return_if_fail (GEDIT_IS_ENCODINGS_OPTION_MENU (dialog->priv->option_menu));
+	g_return_if_fail (GEDIT_IS_ENCODINGS_COMBO_BOX (dialog->priv->option_menu));
 
-	gedit_encodings_option_menu_set_selected_encoding (
-				GEDIT_ENCODINGS_OPTION_MENU (dialog->priv->option_menu),
+	gedit_encodings_combo_box_set_selected_encoding (
+				GEDIT_ENCODINGS_COMBO_BOX (dialog->priv->option_menu),
 				encoding);
 }
 
@@ -381,10 +520,73 @@ const GeditEncoding *
 gedit_file_chooser_dialog_get_encoding (GeditFileChooserDialog *dialog)
 {
 	g_return_val_if_fail (GEDIT_IS_FILE_CHOOSER_DIALOG (dialog), NULL);
-	g_return_val_if_fail (GEDIT_IS_ENCODINGS_OPTION_MENU (dialog->priv->option_menu), NULL);
+	g_return_val_if_fail (GEDIT_IS_ENCODINGS_COMBO_BOX (dialog->priv->option_menu), NULL);
 	g_return_val_if_fail ((gtk_file_chooser_get_action (GTK_FILE_CHOOSER (dialog)) == GTK_FILE_CHOOSER_ACTION_OPEN ||
 			       gtk_file_chooser_get_action (GTK_FILE_CHOOSER (dialog)) == GTK_FILE_CHOOSER_ACTION_SAVE), NULL);
 
-	return gedit_encodings_option_menu_get_selected_encoding (
-				GEDIT_ENCODINGS_OPTION_MENU (dialog->priv->option_menu));
+	return gedit_encodings_combo_box_get_selected_encoding (
+				GEDIT_ENCODINGS_COMBO_BOX (dialog->priv->option_menu));
 }
+
+static void
+set_enum_combo (GtkComboBox *combo,
+                gint         value)
+{
+	GtkTreeIter iter;
+	GtkTreeModel *model;
+
+	model = gtk_combo_box_get_model (combo);
+
+	if (!gtk_tree_model_get_iter_first (model, &iter))
+	{
+		return;
+	}
+
+	do
+	{
+		gint nt;
+
+		gtk_tree_model_get (model, &iter, 1, &nt, -1);
+
+		if (value == nt)
+		{
+			gtk_combo_box_set_active_iter (combo, &iter);
+			break;
+		}
+	} while (gtk_tree_model_iter_next (model, &iter));
+}
+
+void
+gedit_file_chooser_dialog_set_newline_type (GeditFileChooserDialog   *dialog,
+					    GeditDocumentNewlineType  newline_type)
+{
+	g_return_if_fail (GEDIT_IS_FILE_CHOOSER_DIALOG (dialog));
+	g_return_if_fail (gtk_file_chooser_get_action (GTK_FILE_CHOOSER (dialog)) == GTK_FILE_CHOOSER_ACTION_SAVE);
+
+	set_enum_combo (GTK_COMBO_BOX (dialog->priv->newline_combo),
+	                newline_type);
+}
+
+GeditDocumentNewlineType
+gedit_file_chooser_dialog_get_newline_type (GeditFileChooserDialog *dialog)
+{
+	GtkTreeIter iter;
+	GeditDocumentNewlineType newline_type;
+
+	g_return_val_if_fail (GEDIT_IS_FILE_CHOOSER_DIALOG (dialog), GEDIT_DOCUMENT_NEWLINE_TYPE_DEFAULT);
+	g_return_val_if_fail (gtk_file_chooser_get_action (GTK_FILE_CHOOSER (dialog)) == GTK_FILE_CHOOSER_ACTION_SAVE,
+	                      GEDIT_DOCUMENT_NEWLINE_TYPE_DEFAULT);
+
+	gtk_combo_box_get_active_iter (GTK_COMBO_BOX (dialog->priv->newline_combo),
+	                               &iter);
+
+	gtk_tree_model_get (GTK_TREE_MODEL (dialog->priv->newline_store),
+	                    &iter,
+	                    1,
+	                    &newline_type,
+	                    -1);
+
+	return newline_type;
+}
+
+/* ex:ts=8:noet: */
