@@ -35,7 +35,6 @@
 #include <string.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <gconf/gconf-client.h>
 
 #include "gedit-history-entry.h"
 
@@ -60,7 +59,7 @@ struct _GeditHistoryEntryPrivate
 	
 	GtkEntryCompletion *completion;
 	
-	GConfClient        *gconf_client;
+	GSettings          *settings;
 };
 
 G_DEFINE_TYPE(GeditHistoryEntry, gedit_history_entry, GTK_TYPE_COMBO_BOX_ENTRY)
@@ -77,16 +76,17 @@ gedit_history_entry_set_property (GObject      *object,
 
 	entry = GEDIT_HISTORY_ENTRY (object);
 
-	switch (prop_id) {
-	case PROP_HISTORY_ID:
-		entry->priv->history_id = g_value_dup_string (value);
-		break;
-	case PROP_HISTORY_LENGTH:
-		gedit_history_entry_set_history_length (entry,
-						     g_value_get_uint (value));
-		break;
-	default:
-		break;
+	switch (prop_id)
+	{
+		case PROP_HISTORY_ID:
+			entry->priv->history_id = g_value_dup_string (value);
+			break;
+		case PROP_HISTORY_LENGTH:
+			gedit_history_entry_set_history_length (entry,
+								g_value_get_uint (value));
+			break;
+		default:
+			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, spec);
 	}
 }
 
@@ -102,15 +102,16 @@ gedit_history_entry_get_property (GObject    *object,
 
 	priv = GEDIT_HISTORY_ENTRY (object)->priv;
 
-	switch (prop_id) {
-	case PROP_HISTORY_ID:
-		g_value_set_string (value, priv->history_id);
-		break;
-	case PROP_HISTORY_LENGTH:
-		g_value_set_uint (value, priv->history_length);
-		break;
-	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, spec);
+	switch (prop_id)
+	{
+		case PROP_HISTORY_ID:
+			g_value_set_string (value, priv->history_id);
+			break;
+		case PROP_HISTORY_LENGTH:
+			g_value_set_uint (value, priv->history_length);
+			break;
+		default:
+			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, spec);
 	}
 }
 
@@ -132,10 +133,10 @@ gedit_history_entry_finalize (GObject *object)
 	
 	g_free (priv->history_id);
 
-	if (priv->gconf_client != NULL)
+	if (priv->settings != NULL)
 	{
-		g_object_unref (G_OBJECT (priv->gconf_client));
-		priv->gconf_client = NULL;
+		g_object_unref (G_OBJECT (priv->settings));
+		priv->settings = NULL;
 	}
 
 	G_OBJECT_CLASS (gedit_history_entry_parent_class)->finalize (object);
@@ -174,7 +175,7 @@ gedit_history_entry_class_init (GeditHistoryEntryClass *klass)
 
 	/* TODO: Add enable-completion property */
 
-	g_type_class_add_private (object_class, sizeof(GeditHistoryEntryPrivate));
+	g_type_class_add_private (object_class, sizeof (GeditHistoryEntryPrivate));
 }
 
 static GtkListStore *
@@ -188,42 +189,25 @@ get_history_store (GeditHistoryEntry *entry)
 	return (GtkListStore *) store;
 }
 
-static char *
-get_history_key (GeditHistoryEntry *entry)
-{
-	gchar *tmp;
-	gchar *key;
-
-	/*
-	 * We store the data under /apps/gnome-settings/
-	 * like the old GnomeEntry did. Maybe we should
-	 * consider moving it to the /gedit GConf prefix...
-	 * Or maybe we should just switch away from GConf.
-	 */
-
-	tmp = gconf_escape_key (entry->priv->history_id, -1);
-	key = g_strconcat ("/apps/gnome-settings/",
-			   "gedit",
-			   "/history-",
-			   tmp,
-			   NULL);
-	g_free (tmp);
-
-	return key;
-}
-
-static GSList *
-get_history_list (GeditHistoryEntry *entry)
+static gchar **
+get_history_items (GeditHistoryEntry *entry,
+		   gsize             *len)
 {
 	GtkListStore *store;
 	GtkTreeIter iter;
+	GPtrArray *array;
 	gboolean valid;
-	GSList *list = NULL;
+	gint n_children;
 
 	store = get_history_store (entry);
 
 	valid = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (store),
 					       &iter);
+	n_children = gtk_tree_model_iter_n_children (GTK_TREE_MODEL (store),
+						     NULL);
+
+	*len = n_children;
+	array = g_ptr_array_sized_new (*len + 1);
 
 	while (valid)
 	{
@@ -234,35 +218,32 @@ get_history_list (GeditHistoryEntry *entry)
 				    0, &str,
 				    -1);
 
-		list = g_slist_prepend (list, str);
+		g_ptr_array_add (array, str);
 
 		valid = gtk_tree_model_iter_next (GTK_TREE_MODEL (store),
 						  &iter);
 	}
+	
+	g_ptr_array_add (array, NULL);
 
-	return g_slist_reverse (list);
+	return (gchar **)g_ptr_array_free (array, FALSE);
 }
 
 static void
 gedit_history_entry_save_history (GeditHistoryEntry *entry)
 {
-	GSList *gconf_items;
-	gchar *key;
+	gchar **items;
+	gsize len;
 
 	g_return_if_fail (GEDIT_IS_HISTORY_ENTRY (entry));
 
-	gconf_items = get_history_list (entry);
-	key = get_history_key (entry);
+	items = get_history_items (entry, &len);
 
-	gconf_client_set_list (entry->priv->gconf_client,
-			      key,
-			      GCONF_VALUE_STRING,
-			      gconf_items,
-			      NULL);
+	g_settings_set_strv (entry->priv->settings,
+			     entry->priv->history_id,
+			     (const gchar * const *)items, len);
 
-	g_slist_foreach (gconf_items, (GFunc) g_free, NULL);
-	g_slist_free (gconf_items);
-	g_free (key);
+	g_strfreev (items);
 }
 
 static gboolean
@@ -313,7 +294,7 @@ clamp_list_store (GtkListStore *store,
 
 	if (gtk_tree_model_get_iter (GTK_TREE_MODEL (store), &iter, path))
 	{
-		while (1)
+		while (TRUE)
 		{
 			if (!gtk_list_store_remove (store, &iter))
 				break;
@@ -382,39 +363,37 @@ gedit_history_entry_append_text (GeditHistoryEntry *entry,
 static void
 gedit_history_entry_load_history (GeditHistoryEntry *entry)
 {
-	GSList *gconf_items, *l;
+	gchar **items;
 	GtkListStore *store;
 	GtkTreeIter iter;
-	gchar *key;
-	guint i;
+	gsize i;
 
 	g_return_if_fail (GEDIT_IS_HISTORY_ENTRY (entry));
 
 	store = get_history_store (entry);
-	key = get_history_key (entry);
 
-	gconf_items = gconf_client_get_list (entry->priv->gconf_client,
-					     key,
-					     GCONF_VALUE_STRING,
-					     NULL);
+	items = g_settings_get_strv (entry->priv->settings,
+				     entry->priv->history_id,
+				     &i);
+	i = 0;
 
 	gtk_list_store_clear (store);
 
-	for (l = gconf_items, i = 0;
-	     l != NULL && i < entry->priv->history_length;
-	     l = l->next, i++)
+	/* Now the default value is an empty string so we have to take care
+	   of it to not add the empty string in the search list */
+	while (items[i] != NULL && *items[i] != '\0' &&
+	       i < entry->priv->history_length)
 	{
 		gtk_list_store_append (store, &iter);
-		gtk_list_store_set (store, 
+		gtk_list_store_set (store,
 				    &iter,
 				    0,
-				    l->data,
+				    items[i],
 				    -1);
+		i++;
 	}
 
-	g_slist_foreach (gconf_items, (GFunc) g_free, NULL);
-	g_slist_free (gconf_items);
-	g_free (key);
+	g_strfreev (items);
 }
 
 void
@@ -443,7 +422,7 @@ gedit_history_entry_init (GeditHistoryEntry *entry)
 
 	priv->completion = NULL;
 	
-	priv->gconf_client = gconf_client_get_default ();
+	priv->settings = g_settings_new ("org.gnome.gedit.state.history-entry");
 }
 
 void
@@ -564,7 +543,7 @@ gedit_history_entry_new (const gchar *history_id,
 
 	gedit_history_entry_set_enable_completion (GEDIT_HISTORY_ENTRY (ret),
 						   enable_completion);
-						   
+
 	return ret;
 }
 
@@ -616,17 +595,23 @@ gedit_history_entry_set_escape_func (GeditHistoryEntry           *entry,
 	g_return_if_fail (cells->data != NULL && cells->next == NULL);
 
 	if (escape_func != NULL)
+	{
 		gtk_cell_layout_set_cell_data_func (GTK_CELL_LAYOUT (entry),
 						    GTK_CELL_RENDERER (cells->data),
 						    (GtkCellLayoutDataFunc) escape_cell_data_func,
 						    escape_func,
 						    NULL);
+	}
 	else
+	{
 		gtk_cell_layout_set_cell_data_func (GTK_CELL_LAYOUT (entry),
 						    GTK_CELL_RENDERER (cells->data),
 						    NULL,
 						    NULL,
 						    NULL);
+	}
 
 	g_list_free (cells);
 }
+
+/* ex:ts=8:noet: */
