@@ -26,7 +26,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-plugin-manager.c 6851 2009-01-16 12:04:06Z icq $
+ * $Id$
  */
 
 #ifdef HAVE_CONFIG_H
@@ -72,9 +72,11 @@ struct _GeditPluginManagerPrivate
 
 G_DEFINE_TYPE(GeditPluginManager, gedit_plugin_manager, GTK_TYPE_VBOX)
 
-static GeditPluginInfo *plugin_manager_get_selected_plugin (GeditPluginManager *pm); 
-static void plugin_manager_toggle_active (GeditPluginManager *pm, GtkTreeIter *iter, GtkTreeModel *model);
-static void gedit_plugin_manager_finalize (GObject *object);
+static GeditPluginInfo	*plugin_manager_get_selected_plugin	(GeditPluginManager *pm); 
+static void		 plugin_manager_toggle_active		(GeditPluginManager *pm,
+								 GtkTreeIter        *iter,
+								 GtkTreeModel       *model);
+static void		 gedit_plugin_manager_finalize		(GObject            *object);
 
 static void 
 gedit_plugin_manager_class_init (GeditPluginManagerClass *klass)
@@ -335,7 +337,8 @@ plugin_manager_set_active (GeditPluginManager *pm,
 	if (active)
 	{
 		/* activate the plugin */
-		if (!gedit_plugins_engine_activate_plugin (pm->priv->engine, info)) {
+		if (!gedit_plugins_engine_activate_plugin (pm->priv->engine, info))
+		{
 			gedit_debug_message (DEBUG_PLUGINS, "Could not activate %s.\n", 
 					     gedit_plugin_info_get_name (info));
 
@@ -345,7 +348,8 @@ plugin_manager_set_active (GeditPluginManager *pm,
 	else
 	{
 		/* deactivate the plugin */
-		if (!gedit_plugins_engine_deactivate_plugin (pm->priv->engine, info)) {
+		if (!gedit_plugins_engine_deactivate_plugin (pm->priv->engine, info))
+		{
 			gedit_debug_message (DEBUG_PLUGINS, "Could not deactivate %s.\n", 
 					     gedit_plugin_info_get_name (info));
 
@@ -411,10 +415,10 @@ plugin_manager_set_active_all (GeditPluginManager *pm,
 
 	gtk_tree_model_get_iter_first (model, &iter);
 
-	do {
+	do
+	{
 		plugin_manager_set_active (pm, &iter, model, active);
-	}
-	while (gtk_tree_model_iter_next (model, &iter));
+	} while (gtk_tree_model_iter_next (model, &iter));
 }
 
 /* Callback used as the interactive search comparison function */
@@ -765,8 +769,7 @@ plugin_toggled_cb (GeditPluginsEngine *engine,
 			GeditPluginInfo *tinfo;
 			gtk_tree_model_get (model, &iter, INFO_COLUMN, &tinfo, -1);
 			info_found = info == tinfo;
-		}
-		while (!info_found && gtk_tree_model_iter_next (model, &iter));
+		} while (!info_found && gtk_tree_model_iter_next (model, &iter));
 	}
 
 	if (!info_found)
@@ -783,10 +786,8 @@ static void
 gedit_plugin_manager_init (GeditPluginManager *pm)
 {
 	GtkWidget *label;
-	GtkWidget *alignment;
 	GtkWidget *viewport;
 	GtkWidget *hbuttonbox;
-	gchar *markup;
 
 	gedit_debug (DEBUG_PLUGINS);
 
@@ -799,20 +800,12 @@ gedit_plugin_manager_init (GeditPluginManager *pm)
 
 	gtk_box_set_spacing (GTK_BOX (pm), 6);
 
-	label = gtk_label_new (NULL);
-	markup = g_markup_printf_escaped ("<span weight=\"bold\">%s</span>",
-					  _("Active plugins"));
-	gtk_label_set_markup (GTK_LABEL (label), markup);
-	g_free (markup);
+	label = gtk_label_new_with_mnemonic (_("Active _Plugins:"));
 	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	
 	gtk_box_pack_start (GTK_BOX (pm), label, FALSE, TRUE, 0);
 	
-	alignment = gtk_alignment_new (0., 0., 1., 1.);
-	gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
-	gtk_box_pack_start (GTK_BOX (pm), alignment, TRUE, TRUE, 0);
-	
 	viewport = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (viewport),
 					GTK_POLICY_AUTOMATIC,
@@ -820,11 +813,13 @@ gedit_plugin_manager_init (GeditPluginManager *pm)
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (viewport), 
 					     GTK_SHADOW_IN);
 
-	gtk_container_add (GTK_CONTAINER (alignment), viewport);
+	gtk_box_pack_start (GTK_BOX (pm), viewport, TRUE, TRUE, 0);
 
 	pm->priv->tree = gtk_tree_view_new ();
 	gtk_container_add (GTK_CONTAINER (viewport), pm->priv->tree);
 
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), pm->priv->tree);
+
 	hbuttonbox = gtk_hbutton_box_new ();
 	gtk_box_pack_start (GTK_BOX (pm), hbuttonbox, FALSE, FALSE, 0);
 	gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
@@ -895,3 +890,5 @@ GtkWidget *gedit_plugin_manager_new (void)
 {
 	return g_object_new (GEDIT_TYPE_PLUGIN_MANAGER,0);
 }
+
+/* ex:ts=8:noet: */
