@@ -41,10 +41,11 @@
 #include "gedit-plugin.h"
 #include "gedit-debug.h"
 #include "gedit-app.h"
-#include "gedit-prefs-manager.h"
 #include "gedit-plugin-loader.h"
 #include "gedit-object-module.h"
 #include "gedit-dirs.h"
+#include "gedit-settings.h"
+#include "gedit-utils.h"
 
 #define GEDIT_PLUGINS_ENGINE_BASE_KEY "/apps/gedit-2/plugins"
 #define GEDIT_PLUGINS_ENGINE_KEY GEDIT_PLUGINS_ENGINE_BASE_KEY "/active-plugins"
@@ -72,6 +73,8 @@ G_DEFINE_TYPE(GeditPluginsEngine, gedit_plugins_engine, G_TYPE_OBJECT)
 
 struct _GeditPluginsEnginePrivate
 {
+	GSettings *plugin_settings;
+
 	GList *plugin_list;
 	GHashTable *loaders;
 
@@ -80,10 +83,10 @@ struct _GeditPluginsEnginePrivate
 
 GeditPluginsEngine *default_engine = NULL;
 
-static void	gedit_plugins_engine_activate_plugin_real (GeditPluginsEngine *engine,
-							   GeditPluginInfo    *info);
-static void	gedit_plugins_engine_deactivate_plugin_real (GeditPluginsEngine *engine,
-							     GeditPluginInfo    *info);
+static void	gedit_plugins_engine_activate_plugin_real	(GeditPluginsEngine *engine,
+								 GeditPluginInfo    *info);
+static void	gedit_plugins_engine_deactivate_plugin_real	(GeditPluginsEngine *engine,
+								 GeditPluginInfo    *info);
 
 typedef gboolean (*LoadDirCallback)(GeditPluginsEngine *engine, const gchar *filename, gpointer userdata);
 
@@ -282,6 +285,8 @@ gedit_plugins_engine_init (GeditPluginsEngine *engine)
 						    GEDIT_TYPE_PLUGINS_ENGINE,
 						    GeditPluginsEnginePrivate);
 
+	engine->priv->plugin_settings = g_settings_new ("org.gnome.gedit.plugins");
+
 	load_all_plugins (engine);
 
 	/* make sure that the first reactivation will read active plugins
@@ -343,6 +348,20 @@ gedit_plugins_engine_finalize (GObject *object)
 	G_OBJECT_CLASS (gedit_plugins_engine_parent_class)->finalize (object);
 }
 
+static void
+gedit_plugins_engine_dispose (GObject *object)
+{
+	GeditPluginsEngine *engine = GEDIT_PLUGINS_ENGINE (object);
+	
+	if (engine->priv->plugin_settings != NULL)
+	{
+		g_object_unref (engine->priv->plugin_settings);
+		engine->priv->plugin_settings = NULL;
+	}
+	
+	G_OBJECT_CLASS (gedit_plugins_engine_parent_class)->dispose (object);
+}
+
 static void
 gedit_plugins_engine_class_init (GeditPluginsEngineClass *klass)
 {
@@ -350,6 +369,7 @@ gedit_plugins_engine_class_init (GeditPluginsEngineClass *klass)
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
 	object_class->finalize = gedit_plugins_engine_finalize;
+	object_class->dispose = gedit_plugins_engine_dispose;
 	klass->activate_plugin = gedit_plugins_engine_activate_plugin_real;
 	klass->deactivate_plugin = gedit_plugins_engine_deactivate_plugin_real;
 
@@ -446,7 +466,8 @@ ensure_loader (LoaderInfo *info)
 }
 
 static GeditPluginLoader *
-get_plugin_loader (GeditPluginsEngine *engine, GeditPluginInfo *info)
+get_plugin_loader (GeditPluginsEngine *engine,
+		   GeditPluginInfo    *info)
 {
 	const gchar *loader_id;
 	LoaderInfo *loader_info;
@@ -510,7 +531,7 @@ gedit_plugins_engine_get_plugin_list (GeditPluginsEngine *engine)
 
 static gint
 compare_plugin_info_and_name (GeditPluginInfo *info,
-			      const gchar *module_name)
+			      const gchar     *module_name)
 {
 	return strcmp (gedit_plugin_info_get_module_name (info), module_name);
 }
@@ -543,7 +564,9 @@ save_active_plugin_list (GeditPluginsEngine *engine)
 		}
 	}
 
-	gedit_prefs_manager_set_active_plugins (active_plugins);
+	gedit_settings_set_list (engine->priv->plugin_settings,
+				 GEDIT_SETTINGS_ACTIVE_PLUGINS,
+				 active_plugins);
 
 	g_slist_free (active_plugins);
 }
@@ -589,7 +612,7 @@ load_plugin (GeditPluginsEngine *engine,
 
 static void
 gedit_plugins_engine_activate_plugin_real (GeditPluginsEngine *engine,
-					   GeditPluginInfo *info)
+					   GeditPluginInfo    *info)
 {
 	const GList *wins;
 
@@ -641,7 +664,7 @@ call_plugin_deactivate (GeditPlugin *plugin,
 
 static void
 gedit_plugins_engine_deactivate_plugin_real (GeditPluginsEngine *engine,
-					     GeditPluginInfo *info)
+					     GeditPluginInfo    *info)
 {
 	const GList *wins;
 	GeditPluginLoader *loader;
@@ -689,7 +712,7 @@ gedit_plugins_engine_deactivate_plugin (GeditPluginsEngine *engine,
 
 void
 gedit_plugins_engine_activate_plugins (GeditPluginsEngine *engine,
-					GeditWindow        *window)
+					GeditWindow       *window)
 {
 	GSList *active_plugins = NULL;
 	GList *pl;
@@ -702,7 +725,8 @@ gedit_plugins_engine_activate_plugins (GeditPluginsEngine *engine,
 	/* the first time, we get the 'active' plugins from gconf */
 	if (engine->priv->activate_from_prefs)
 	{
-		active_plugins = gedit_prefs_manager_get_active_plugins ();
+		active_plugins = gedit_settings_get_list (engine->priv->plugin_settings,
+							  GEDIT_SETTINGS_ACTIVE_PLUGINS);
 	}
 
 	for (pl = engine->priv->plugin_list; pl; pl = pl->next)
@@ -713,16 +737,22 @@ gedit_plugins_engine_activate_plugins (GeditPluginsEngine *engine,
 		    g_slist_find_custom (active_plugins,
 					 gedit_plugin_info_get_module_name (info),
 					 (GCompareFunc)strcmp) == NULL)
+		{
 			continue;
+		}
 		
 		/* If plugin is not active, don't try to activate/load it */
 		if (!engine->priv->activate_from_prefs && 
 		    !gedit_plugin_info_is_active (info))
+		{
 			continue;
+		}
 
 		if (load_plugin (engine, info))
+		{
 			gedit_plugin_activate (info->plugin,
 					       window);
+		}
 	}
 	
 	if (engine->priv->activate_from_prefs)
@@ -740,7 +770,7 @@ gedit_plugins_engine_activate_plugins (GeditPluginsEngine *engine,
 
 void
 gedit_plugins_engine_deactivate_plugins (GeditPluginsEngine *engine,
-					  GeditWindow        *window)
+					  GeditWindow       *window)
 {
 	GList *pl;
 	
@@ -766,7 +796,7 @@ gedit_plugins_engine_deactivate_plugins (GeditPluginsEngine *engine,
 
 void
 gedit_plugins_engine_update_plugins_ui (GeditPluginsEngine *engine,
-					 GeditWindow        *window)
+					 GeditWindow       *window)
 {
 	GList *pl;
 
@@ -829,7 +859,8 @@ gedit_plugins_engine_active_plugins_changed (GeditPluginsEngine *engine)
 
 	gedit_debug (DEBUG_PLUGINS);
 
-	active_plugins = gedit_prefs_manager_get_active_plugins ();
+	active_plugins = gedit_settings_get_list (engine->priv->plugin_settings,
+						  GEDIT_SETTINGS_ACTIVE_PLUGINS);
 
 	for (pl = engine->priv->plugin_list; pl; pl = pl->next)
 	{
@@ -859,4 +890,5 @@ gedit_plugins_engine_rescan_plugins (GeditPluginsEngine *engine)
 	
 	load_all_plugins (engine);
 }
+
 /* ex:ts=8:noet: */
