@@ -46,13 +46,13 @@
 
 #include "gedit-debug.h"
 #include "gedit-plugins-engine.h"
-#include "gedit-prefs-manager-app.h"
 #include "gedit-metadata-manager.h"
 #include "gedit-window.h"
 #include "gedit-app.h"
 #include "gedit-commands.h"
 #include "dialogs/gedit-close-confirmation-dialog.h"
 #include "smclient/eggsmclient.h"
+#include "gseal-gtk-compat.h"
 
 /* The master client we use for SM */
 static EggSMClient *master_client = NULL;
@@ -75,7 +75,7 @@ save_window_session (GKeyFile    *state_file,
 	GList *docs, *l;
 	GPtrArray *doc_array;
 	GeditDocument *active_document;
-	gchar *uri;
+	gchar *uri = NULL;
 
 	gedit_debug (DEBUG_SESSION);
 
@@ -87,18 +87,27 @@ save_window_session (GKeyFile    *state_file,
 
 	panel = gedit_window_get_side_panel (window);
 	g_key_file_set_boolean (state_file, group_name, "side-panel-visible",
-				GTK_WIDGET_VISIBLE (panel));
+				gtk_widget_get_visible (GTK_WIDGET (panel)));
 
 	panel = gedit_window_get_bottom_panel (window);
 	g_key_file_set_boolean (state_file, group_name, "bottom-panel-visible",
-				GTK_WIDGET_VISIBLE (panel));
+				gtk_widget_get_visible (GTK_WIDGET (panel)));
 
 	active_document = gedit_window_get_active_document (window);
 	if (active_document)
 	{
-	        uri = gedit_document_get_uri (active_document);
-	        g_key_file_set_string (state_file, group_name,
+		GFile *location;
+
+		location = gedit_document_get_location (active_document);
+		if (location)
+		{
+			uri = g_file_get_uri (location);
+			g_object_unref (location);
+		}
+
+		g_key_file_set_string (state_file, group_name,
 				       "active-document", uri);
+		g_free (uri);
 	}
 
 	docs = gedit_window_get_documents (window);
@@ -106,24 +115,28 @@ save_window_session (GKeyFile    *state_file,
 	doc_array = g_ptr_array_new ();
 	for (l = docs; l != NULL; l = g_list_next (l))
 	{
-		uri = gedit_document_get_uri (GEDIT_DOCUMENT (l->data));
+		GFile *location;
+
+		location = gedit_document_get_location (GEDIT_DOCUMENT (l->data));
+		if (location)
+		{
+			uri = g_file_get_uri (location);
+			g_object_unref (location);
+		}
 
 		if (uri != NULL)
-		        g_ptr_array_add (doc_array, uri);
-			  
+			g_ptr_array_add (doc_array, uri);
 	}
-	g_list_free (docs);	
+	g_list_free (docs);
 
 	if (doc_array->len)
 	{
-	        int i;
- 
 		g_key_file_set_string_list (state_file, group_name,
 					    "documents",
 					    (const char **)doc_array->pdata,
 					    doc_array->len);
-		for (i = 0; i < doc_array->len; i++)
-		        g_free (doc_array->pdata[i]);
+
+		g_ptr_array_foreach (doc_array, (GFunc) g_free, NULL);
 	}
 	g_ptr_array_free (doc_array, TRUE);
 }
@@ -254,8 +267,10 @@ close_confirmation_dialog_response_handler (GeditCloseConfirmationDialog *dlg,
 		default:
 			/* disconnect window_state_changed where needed */
 			for (l = window_dirty_list; l != NULL; l = l->next)
+			{
 				g_signal_handlers_disconnect_by_func (window,
 						window_state_change, NULL);
+			}
 			g_slist_free (window_dirty_list);
 			window_dirty_list = NULL;
 
@@ -316,7 +331,7 @@ show_confirmation_dialog (GeditWindow *window)
 }
 
 static void
-ask_next_confirmation ()
+ask_next_confirmation (void)
 {
 	g_return_if_fail (window_dirty_list != NULL);
 
@@ -329,7 +344,8 @@ ask_next_confirmation ()
 
 /* quit_requested handler for the master client */
 static void
-client_quit_requested_cb (EggSMClient *client, gpointer data)
+client_quit_requested_cb (EggSMClient *client,
+			  gpointer     data)
 {
 	GeditApp *app;
 	const GList *l;
@@ -367,7 +383,8 @@ client_quit_requested_cb (EggSMClient *client, gpointer data)
 
 /* quit handler for the master client */
 static void
-client_quit_cb (EggSMClient *client, gpointer data)
+client_quit_cb (EggSMClient *client,
+		gpointer     data)
 {
 #if 0
 	gedit_debug (DEBUG_SESSION);
@@ -407,7 +424,7 @@ gedit_session_init (void)
 	gedit_debug (DEBUG_SESSION);
 	
 	if (master_client)
-	  return;
+		return;
 
 	master_client = egg_sm_client_get ();
 	g_signal_connect (master_client,
@@ -451,7 +468,8 @@ gedit_session_is_restored (void)
 }
 
 static void
-parse_window (GKeyFile *state_file, const char *group_name)
+parse_window (GKeyFile  *state_file,
+	     const char *group_name)
 {
 	GeditWindow *window;
 	gchar *role, *active_document, **documents;
@@ -537,29 +555,38 @@ parse_window (GKeyFile *state_file, const char *group_name)
 						"documents", NULL, NULL);
 	if (documents)
 	{
-	        int i;
+		gint i;
 		gboolean jump_to = FALSE;
-  
+
 		for (i = 0; documents[i]; i++)
 		{
-		        if (active_document != NULL)
-			        jump_to = strcmp (active_document,
+			GFile *location;
+
+			if (active_document != NULL)
+			{
+				jump_to = strcmp (active_document,
 						  documents[i]) == 0;
-  
+			}
+
 			gedit_debug_message (DEBUG_SESSION,
 					     "URI: %s (%s)",
 					     documents[i],
 					     jump_to ? "active" : "not active");
-			gedit_window_create_tab_from_uri (window,
-							  documents[i],
-							  NULL,
-							  0,
-							  FALSE,
-							  jump_to);
+
+			location = g_file_new_for_uri (documents[i]);
+			gedit_window_create_tab_from_location (window,
+							       location,
+							       NULL,
+							       0,
+							       0,
+							       FALSE,
+							       jump_to);
+			if (location)
+				g_object_unref (location);
 		}
 		g_strfreev (documents);
 	}
- 
+
 	g_free (active_document);
 	
 	gtk_widget_show (GTK_WIDGET (window));
@@ -599,3 +626,5 @@ gedit_session_load (void)
 
 	return TRUE;
 }
+
+/* ex:ts=8:noet: */
