@@ -42,8 +42,8 @@
 #include "gedit-print-preview.h"
 #include "gedit-progress-message-area.h"
 #include "gedit-debug.h"
-#include "gedit-prefs-manager-app.h"
 #include "gedit-enum-types.h"
+#include "gedit-settings.h"
 
 #if !GTK_CHECK_VERSION (2, 17, 1)
 #include "gedit-message-area.h"
@@ -55,6 +55,7 @@
 
 struct _GeditTabPrivate
 {
+	GSettings	       *editor;
 	GeditTabState	        state;
 	
 	GtkWidget	       *view;
@@ -236,6 +237,12 @@ gedit_tab_dispose (GObject *object)
 		tab->priv->tmp_save_location = NULL;
 	}
 
+	if (tab->priv->editor != NULL)
+	{
+		g_object_unref (tab->priv->editor);
+		tab->priv->editor = NULL;
+	}
+
 	G_OBJECT_CLASS (gedit_tab_parent_class)->dispose (object);
 }
 
@@ -253,16 +260,37 @@ gedit_tab_finalize (GObject *object)
 	G_OBJECT_CLASS (gedit_tab_parent_class)->finalize (object);
 }
 
+static void
+gedit_tab_grab_focus (GtkWidget *widget)
+{
+	GeditTab *tab = GEDIT_TAB (widget);
+	
+	GTK_WIDGET_CLASS (gedit_tab_parent_class)->grab_focus (widget);
+	
+	if (tab->priv->message_area != NULL)
+	{
+		gtk_widget_grab_focus (tab->priv->message_area);
+	}
+	else
+	{
+		gtk_widget_grab_focus (GTK_WIDGET (gedit_tab_get_view (tab)));
+	}
+}
+
 static void 
 gedit_tab_class_init (GeditTabClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
+	GtkWidgetClass *gtkwidget_class = GTK_WIDGET_CLASS (klass);
 
 	object_class->dispose = gedit_tab_dispose;
 	object_class->finalize = gedit_tab_finalize;
+	object_class->dispose = gedit_tab_dispose;
 	object_class->get_property = gedit_tab_get_property;
 	object_class->set_property = gedit_tab_set_property;
 	
+	gtkwidget_class->grab_focus = gedit_tab_grab_focus;
+	
 	g_object_class_install_property (object_class,
 					 PROP_NAME,
 					 g_param_spec_string ("name",
@@ -377,6 +405,10 @@ set_view_properties_according_to_state (GeditTab      *tab,
 					GeditTabState  state)
 {
 	gboolean val;
+	gboolean hl_current_line;
+	
+	hl_current_line = g_settings_get_boolean (tab->priv->editor,
+						  GEDIT_SETTINGS_HIGHLIGHT_CURRENT_LINE);
 
 	val = ((state == GEDIT_TAB_STATE_NORMAL) &&
 	       (tab->priv->print_preview == NULL) &&
@@ -389,7 +421,7 @@ set_view_properties_according_to_state (GeditTab      *tab,
 
 	val = ((state != GEDIT_TAB_STATE_LOADING) &&
 	       (state != GEDIT_TAB_STATE_CLOSING) &&
-	       (gedit_prefs_manager_get_highlight_current_line ()));
+	       (hl_current_line));
 	gtk_source_view_set_highlight_current_line (GTK_SOURCE_VIEW (tab->priv->view), val);
 }
 
@@ -505,11 +537,12 @@ io_loading_error_message_area_response (GtkWidget *message_area,
 	g_return_if_fail (GEDIT_IS_VIEW (view));
 
 	location = gedit_document_get_location (doc);
-	g_return_if_fail (location != NULL);
 
 	switch (response_id)
 	{
 		case GTK_RESPONSE_OK:
+			g_return_if_fail (location != NULL);
+
 			encoding = gedit_conversion_error_message_area_get_encoding (
 					GTK_WIDGET (message_area));
 
@@ -540,13 +573,19 @@ io_loading_error_message_area_response (GtkWidget *message_area,
 			set_message_area (tab, NULL);
 			break;
 		default:
-			_gedit_recent_remove (GEDIT_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (tab))), location);
+			if (location != NULL)
+			{
+				_gedit_recent_remove (GEDIT_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (tab))), location);
+			}
 
 			remove_tab (tab);
 			break;
 	}
 
-	g_object_unref (location);
+	if (location != NULL)
+	{
+		g_object_unref (location);
+	}
 }
 
 static void 
@@ -932,7 +971,10 @@ document_loaded (GeditDocument *document,
 		}
 		else
 		{
-			_gedit_recent_remove (GEDIT_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (tab))), location);
+			if (location)
+			{
+				_gedit_recent_remove (GEDIT_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (tab))), location);
+			}
 
 			if (tab->priv->state == GEDIT_TAB_STATE_LOADING_ERROR)
 			{
@@ -970,23 +1012,28 @@ document_loaded (GeditDocument *document,
 
 		gtk_widget_show (emsg);
 
-		g_object_unref (location);
+		if (location)
+		{
+			g_object_unref (location);
+		}
 
 		return;
 	}
 	else
 	{
-		gchar *mime;
 		GList *all_documents;
 		GList *l;
 
-		g_return_if_fail (location != NULL);
+		if (location != NULL)
+		{
+			gchar *mime;
+			mime = gedit_document_get_mime_type (document);
 
-		mime = gedit_document_get_mime_type (document);
-		_gedit_recent_add (GEDIT_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (tab))),
-				   location,
-				   mime);
-		g_free (mime);
+			_gedit_recent_add (GEDIT_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (tab))),
+					   location,
+					   mime);
+			g_free (mime);
+		}
 
 		if (error &&
 		    error->domain == GEDIT_DOCUMENT_ERROR &&
@@ -1033,7 +1080,7 @@ document_loaded (GeditDocument *document,
 
 				loc = gedit_document_get_location (d);
 
-				if ((loc != NULL) &&
+				if (loc != NULL && location != NULL &&
 			    	    g_file_equal (location, loc))
 			    	{
 			    		GtkWidget *w;
@@ -1074,14 +1121,24 @@ document_loaded (GeditDocument *document,
 		g_list_free (all_documents);
 
 		gedit_tab_set_state (tab, GEDIT_TAB_STATE_NORMAL);
-		
+
+		if (location == NULL)
+		{
+			/* FIXME: hackish */
+			gtk_text_buffer_set_modified (GTK_TEXT_BUFFER (gedit_tab_get_document (tab)),
+			                              TRUE);
+		}
+
 		install_auto_save_timeout_if_needed (tab);
 
 		tab->priv->ask_if_externally_modified = TRUE;
 	}
 
  end:
-	g_object_unref (location);
+ 	if (location)
+ 	{
+		g_object_unref (location);
+	}
 
 	tab->priv->tmp_line_pos = 0;
 	tab->priv->tmp_encoding = NULL;
@@ -1264,6 +1321,7 @@ recoverable_saving_error_message_area_response (GtkWidget *message_area,
 					tab->priv->tmp_save_location,
 					tab->priv->tmp_encoding,
 					gedit_document_get_newline_type (doc),
+					gedit_document_get_compression_type (doc),
 					tab->priv->save_flags);
 	}
 	else
@@ -1497,7 +1555,7 @@ view_focused_in (GtkWidget     *widget,
 
 static GMountOperation *
 tab_mount_operation_factory (GeditDocument *doc,
-			     gpointer userdata)
+			     gpointer       userdata)
 {
 	GeditTab *tab = GEDIT_TAB (userdata);
 	GtkWidget *window;
@@ -1512,9 +1570,13 @@ gedit_tab_init (GeditTab *tab)
 	GtkWidget *sw;
 	GeditDocument *doc;
 	GeditLockdownMask lockdown;
+	gboolean auto_save;
+	gint auto_save_interval;
 
 	tab->priv = GEDIT_TAB_GET_PRIVATE (tab);
 
+	tab->priv->editor = g_settings_new ("org.gnome.gedit.preferences.editor");
+
 	tab->priv->state = GEDIT_TAB_STATE_NORMAL;
 
 	tab->priv->not_editable = FALSE;
@@ -1532,14 +1594,20 @@ gedit_tab_init (GeditTab *tab)
 					GTK_POLICY_AUTOMATIC);
 
 	/* Manage auto save data */
+	auto_save = g_settings_get_boolean (tab->priv->editor,
+					    GEDIT_SETTINGS_AUTO_SAVE);
+	g_settings_get (tab->priv->editor, GEDIT_SETTINGS_AUTO_SAVE_INTERVAL,
+			"u", &auto_save_interval);
+	
 	lockdown = gedit_app_get_lockdown (gedit_app_get_default ());
-	tab->priv->auto_save = gedit_prefs_manager_get_auto_save () &&
+	tab->priv->auto_save = auto_save &&
 			       !(lockdown & GEDIT_LOCKDOWN_SAVE_TO_DISK);
 	tab->priv->auto_save = (tab->priv->auto_save != FALSE);
 
-	tab->priv->auto_save_interval = gedit_prefs_manager_get_auto_save_interval ();
+	tab->priv->auto_save_interval = auto_save_interval;
+	/* FIXME
 	if (tab->priv->auto_save_interval <= 0)
-		tab->priv->auto_save_interval = GPM_DEFAULT_AUTO_SAVE_INTERVAL;
+		tab->priv->auto_save_interval = GPM_DEFAULT_AUTO_SAVE_INTERVAL;*/
 
 	/* Create the view */
 	doc = gedit_document_new ();
@@ -1631,6 +1699,28 @@ _gedit_tab_new_from_location (GFile               *location,
 	return GTK_WIDGET (tab);
 }
 
+GtkWidget *
+_gedit_tab_new_from_stream (GInputStream        *stream,
+                            const GeditEncoding *encoding,
+                            gint                 line_pos,
+                            gint                 column_pos)
+{
+	GeditTab *tab;
+
+	g_return_val_if_fail (G_IS_INPUT_STREAM (stream), NULL);
+
+	tab = GEDIT_TAB (_gedit_tab_new ());
+
+	_gedit_tab_load_stream (tab,
+	                        stream,
+	                        encoding,
+	                        line_pos,
+	                        column_pos);
+
+	return GTK_WIDGET (tab);
+
+}
+
 /**
  * gedit_tab_get_view:
  * @tab: a #GeditTab
@@ -2027,6 +2117,41 @@ _gedit_tab_load (GeditTab            *tab,
 			     create);
 }
 
+void
+_gedit_tab_load_stream (GeditTab            *tab,
+                        GInputStream        *stream,
+                        const GeditEncoding *encoding,
+                        gint                 line_pos,
+                        gint                 column_pos)
+{
+	GeditDocument *doc;
+
+	g_return_if_fail (GEDIT_IS_TAB (tab));
+	g_return_if_fail (G_IS_INPUT_STREAM (stream));
+	g_return_if_fail (tab->priv->state == GEDIT_TAB_STATE_NORMAL);
+
+	doc = gedit_tab_get_document (tab);
+	g_return_if_fail (GEDIT_IS_DOCUMENT (doc));
+
+	gedit_tab_set_state (tab, GEDIT_TAB_STATE_LOADING);
+
+	tab->priv->tmp_line_pos = line_pos;
+	tab->priv->tmp_column_pos = column_pos;
+	tab->priv->tmp_encoding = encoding;
+
+	if (tab->priv->auto_save_timeout > 0)
+	{
+		remove_auto_save_timeout (tab);
+	}
+
+	gedit_document_load_stream (doc,
+	                            stream,
+	                            encoding,
+	                            line_pos,
+	                            column_pos);
+
+}
+
 void
 _gedit_tab_revert (GeditTab *tab)
 {
@@ -2177,10 +2302,11 @@ gedit_tab_auto_save (GeditTab *tab)
 }
 
 void
-_gedit_tab_save_as (GeditTab                 *tab,
-                    GFile                    *location,
-                    const GeditEncoding      *encoding,
-                    GeditDocumentNewlineType  newline_type)
+_gedit_tab_save_as (GeditTab                     *tab,
+                    GFile                        *location,
+                    const GeditEncoding          *encoding,
+                    GeditDocumentNewlineType      newline_type,
+                    GeditDocumentCompressionType  compression_type)
 {
 	GeditDocument *doc;
 	GeditDocumentSaveFlags save_flags;
@@ -2226,8 +2352,12 @@ _gedit_tab_save_as (GeditTab                 *tab,
 	if (tab->priv->auto_save_timeout > 0)
 		remove_auto_save_timeout (tab);
 
-	gedit_document_save_as (doc, location, encoding, newline_type,
-				tab->priv->save_flags);
+	gedit_document_save_as (doc,
+	                        location,
+	                        encoding,
+	                        newline_type,
+	                        compression_type,
+	                        tab->priv->save_flags);
 }
 
 #define GEDIT_PAGE_SETUP_KEY "gedit-page-setup-key"
@@ -2356,7 +2486,7 @@ done_printing_cb (GeditPrintJob       *job,
 		set_message_area (tab, NULL); /* destroy the message area */
 	}
 
-	// TODO: check status and error
+	/* TODO: check status and error */
 
 	if (result ==  GEDIT_PRINT_JOB_RESULT_OK)
 	{
@@ -2415,7 +2545,7 @@ show_preview_cb (GeditPrintJob       *job,
 		 GeditPrintPreview   *preview,
 		 GeditTab            *tab)
 {
-//	g_return_if_fail (tab->priv->state == GEDIT_TAB_STATE_PRINT_PREVIEWING);
+	/* g_return_if_fail (tab->priv->state == GEDIT_TAB_STATE_PRINT_PREVIEWING); */
 	g_return_if_fail (tab->priv->print_preview == NULL);
 
 	set_message_area (tab, NULL); /* destroy the message area */
@@ -2509,13 +2639,17 @@ show_printing_message_area (GeditTab *tab, gboolean preview)
 	GtkWidget *area;
 
 	if (preview)
+	{
 		area = gedit_progress_message_area_new (GTK_STOCK_PRINT_PREVIEW,
 							"",
 							TRUE);
+	}
 	else
+	{
 		area = gedit_progress_message_area_new (GTK_STOCK_PRINT,
 							"",
 							TRUE);
+	}
 
 	g_signal_connect (area,
 			  "response",
@@ -2623,7 +2757,7 @@ gedit_tab_print_or_print_preview (GeditTab                *tab,
 				     GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (tab))),
 				     &error);
 
-	// TODO: manage res in the correct way
+	/* TODO: manage res in the correct way */
 	if (res == GTK_PRINT_OPERATION_RESULT_ERROR)
 	{
 		/* FIXME: go in error state */
@@ -2635,7 +2769,7 @@ gedit_tab_print_or_print_preview (GeditTab                *tab,
 }
 
 void 
-_gedit_tab_print (GeditTab     *tab)
+_gedit_tab_print (GeditTab *tab)
 {
 	g_return_if_fail (GEDIT_IS_TAB (tab));
 
@@ -2652,7 +2786,7 @@ _gedit_tab_print (GeditTab     *tab)
 }
 
 void
-_gedit_tab_print_preview (GeditTab     *tab)
+_gedit_tab_print_preview (GeditTab *tab)
 {
 	g_return_if_fail (GEDIT_IS_TAB (tab));
 
@@ -2684,7 +2818,9 @@ _gedit_tab_can_close (GeditTab *tab)
 	    (ts == GEDIT_TAB_STATE_LOADING_ERROR) ||
 	    (ts == GEDIT_TAB_STATE_REVERTING)     ||
 	    (ts == GEDIT_TAB_STATE_REVERTING_ERROR)) /* CHECK: I'm not sure this is the right behavior for REVERTING ERROR */
+	{
 		return TRUE;
+	}
 
 	/* Do not close tab with saving errors */
 	if (ts == GEDIT_TAB_STATE_SAVING_ERROR)
@@ -2851,4 +2987,5 @@ gedit_tab_set_info_bar (GeditTab  *tab,
 	/* FIXME: this can cause problems with the tab state machine */
 	set_message_area (tab, info_bar);
 }
+
 /* ex:ts=8:noet: */
