@@ -1,19 +1,19 @@
 /*
- * gedit-file-bookmarks-store.c - Gedit plugin providing easy file access 
+ * gedit-file-bookmarks-store.c - Gedit plugin providing easy file access
  * from the sidepanel
- *
+ * 
  * Copyright (C) 2006 - Jesse van den Kieboom <jesse@icecrew.nl>
- *
+ * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- *
+ * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
+ * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
@@ -32,38 +32,39 @@
 		G_TYPE_INSTANCE_GET_PRIVATE((object), GEDIT_TYPE_FILE_BOOKMARKS_STORE, \
 		GeditFileBookmarksStorePrivate))
 
-struct _GeditFileBookmarksStorePrivate 
+struct _GeditFileBookmarksStorePrivate
 {
-	GVolumeMonitor * volume_monitor;
-	GFileMonitor * bookmarks_monitor;
+	GVolumeMonitor *volume_monitor;
+	GFileMonitor *bookmarks_monitor;
 };
 
-static void remove_node               (GtkTreeModel * model, 
-                                       GtkTreeIter * iter);
+static void remove_node               (GtkTreeModel            *model,
+                                       GtkTreeIter             *iter);
 
-static void on_fs_changed             (GVolumeMonitor 		*monitor,
-                                       GObject 			*object,
-                                       GeditFileBookmarksStore 	*model);
-                                       
-static void on_bookmarks_file_changed (GFileMonitor * monitor,
-				       GFile * file,
-				       GFile * other_file,
-				       GFileMonitorEvent event_type,
-				       GeditFileBookmarksStore * model);
-static gboolean find_with_flags       (GtkTreeModel * model, 
-                                       GtkTreeIter * iter,
-                                       gpointer obj, 
-                                       guint flags,
-                                       guint notflags);
+static void on_fs_changed             (GVolumeMonitor          *monitor,
+                                       GObject                 *object,
+                                       GeditFileBookmarksStore *model);
+
+static void on_bookmarks_file_changed (GFileMonitor            *monitor,
+				       GFile                   *file,
+				       GFile                   *other_file,
+				       GFileMonitorEvent        event_type,
+				       GeditFileBookmarksStore *model);
+static gboolean find_with_flags       (GtkTreeModel            *model,
+                                       GtkTreeIter             *iter,
+                                       gpointer                 obj,
+                                       guint                    flags,
+                                       guint                    notflags);
 
 GEDIT_PLUGIN_DEFINE_TYPE(GeditFileBookmarksStore, gedit_file_bookmarks_store, GTK_TYPE_TREE_STORE)
 
 static void
-gedit_file_bookmarks_store_dispose (GObject * object)
+gedit_file_bookmarks_store_dispose (GObject *object)
 {
 	GeditFileBookmarksStore *obj = GEDIT_FILE_BOOKMARKS_STORE (object);
 
-	if (obj->priv->volume_monitor != NULL) {
+	if (obj->priv->volume_monitor != NULL)
+	{
 		g_signal_handlers_disconnect_by_func (obj->priv->volume_monitor,
 						      on_fs_changed,
 						      obj);
@@ -72,7 +73,8 @@ gedit_file_bookmarks_store_dispose (GObject * object)
 		obj->priv->volume_monitor = NULL;
 	}
 
-	if (obj->priv->bookmarks_monitor != NULL) {
+	if (obj->priv->bookmarks_monitor != NULL)
+	{
 		g_object_unref (obj->priv->bookmarks_monitor);
 		obj->priv->bookmarks_monitor = NULL;
 	}
@@ -81,7 +83,7 @@ gedit_file_bookmarks_store_dispose (GObject * object)
 }
 
 static void
-gedit_file_bookmarks_store_finalize (GObject * object)
+gedit_file_bookmarks_store_finalize (GObject *object)
 {
 	G_OBJECT_CLASS (gedit_file_bookmarks_store_parent_class)->finalize (object);
 }
@@ -98,19 +100,19 @@ gedit_file_bookmarks_store_class_init (GeditFileBookmarksStoreClass *klass)
 }
 
 static void
-gedit_file_bookmarks_store_init (GeditFileBookmarksStore * obj)
+gedit_file_bookmarks_store_init (GeditFileBookmarksStore *obj)
 {
 	obj->priv = GEDIT_FILE_BOOKMARKS_STORE_GET_PRIVATE (obj);
 }
 
 /* Private */
 static void
-add_node (GeditFileBookmarksStore *model, 
-	  GdkPixbuf 		  *pixbuf,
-	  const gchar 		  *name, 
-	  GObject 		  *obj, 
-	  guint 		   flags, 
-	  GtkTreeIter 		  *iter)
+add_node (GeditFileBookmarksStore *model,
+	  GdkPixbuf               *pixbuf,
+	  const gchar             *name,
+	  GObject                 *obj,
+	  guint                    flags,
+	  GtkTreeIter             *iter)
 {
 	GtkTreeIter newiter;
 
@@ -128,11 +130,11 @@ add_node (GeditFileBookmarksStore *model,
 }
 
 static gboolean
-add_file (GeditFileBookmarksStore *model, 
-	  GFile 		  *file,
-	  const gchar 		  *name, 
-	  guint 		   flags, 
-	  GtkTreeIter 		  *iter)
+add_file (GeditFileBookmarksStore *model,
+	  GFile                   *file,
+	  const gchar             *name,
+	  guint                    flags,
+	  GtkTreeIter             *iter)
 {
 	GdkPixbuf *pixbuf = NULL;
 	gboolean native;
@@ -140,9 +142,8 @@ add_file (GeditFileBookmarksStore *model,
 
 	native = g_file_is_native (file);
 
-	if (native && !g_file_query_exists (file, NULL)) {
+	if (native && !g_file_query_exists (file, NULL))
 		return FALSE;
-	}
 
 	if (flags & GEDIT_FILE_BOOKMARKS_STORE_IS_HOME)
 		pixbuf = gedit_file_browser_utils_pixbuf_from_theme ("user-home", GTK_ICON_SIZE_MENU);
@@ -151,20 +152,19 @@ add_file (GeditFileBookmarksStore *model,
 	else if (flags & GEDIT_FILE_BOOKMARKS_STORE_IS_ROOT)
 		pixbuf = gedit_file_browser_utils_pixbuf_from_theme ("drive-harddisk", GTK_ICON_SIZE_MENU);
 
-	if (pixbuf == NULL) {
+	if (pixbuf == NULL)
+	{
 		/* getting the icon is a sync get_info call, so we just do it for local files */
-		if (native) {
+		if (native)
 			pixbuf = gedit_file_browser_utils_pixbuf_from_file (file, GTK_ICON_SIZE_MENU);
-		} else {
+		else
 			pixbuf = gedit_file_browser_utils_pixbuf_from_theme ("folder", GTK_ICON_SIZE_MENU);
-		}
 	}
 
-	if (name == NULL) {
+	if (name == NULL)
 		newname = gedit_file_browser_utils_file_basename (file);
-	} else {
+	else
 		newname = g_strdup (name);
-	}
 
 	add_node (model, pixbuf, newname, G_OBJECT (file), flags, iter);
 
@@ -177,32 +177,36 @@ add_file (GeditFileBookmarksStore *model,
 }
 
 static void
-check_mount_separator (GeditFileBookmarksStore * model, guint flags,
-			gboolean added)
+check_mount_separator (GeditFileBookmarksStore *model,
+		       guint                    flags,
+		       gboolean                 added)
 {
 	GtkTreeIter iter;
 	gboolean found;
 
 	found =
 	    find_with_flags (GTK_TREE_MODEL (model), &iter, NULL,
-			     flags |
-			     GEDIT_FILE_BOOKMARKS_STORE_IS_SEPARATOR, 0);
+			     flags | GEDIT_FILE_BOOKMARKS_STORE_IS_SEPARATOR,
+			     0);
 
-	if (added && !found) {
+	if (added && !found)
+	{
 		/* Add the separator */
 		add_node (model, NULL, NULL, NULL,
 			  flags | GEDIT_FILE_BOOKMARKS_STORE_IS_SEPARATOR,
 			  NULL);
-	} else if (!added && found) {
+	}
+	else if (!added && found)
+	{
 		remove_node (GTK_TREE_MODEL (model), &iter);
 	}
 }
 
 static void
-init_special_directories (GeditFileBookmarksStore * model)
+init_special_directories (GeditFileBookmarksStore *model)
 {
 	gchar const *path;
-	GFile * file;
+	GFile *file;
 
 	path = g_get_home_dir ();
 	if (path != NULL)
@@ -227,14 +231,14 @@ init_special_directories (GeditFileBookmarksStore * model)
 	{
 		file = g_file_new_for_path (path);
 		add_file (model, file, NULL, GEDIT_FILE_BOOKMARKS_STORE_IS_DOCUMENTS |
-			 GEDIT_FILE_BOOKMARKS_STORE_IS_SPECIAL_DIR, NULL);
+			  GEDIT_FILE_BOOKMARKS_STORE_IS_SPECIAL_DIR, NULL);
 		g_object_unref (file);
 	}
-	
+
 	file = g_file_new_for_uri ("file:///");
 	add_file (model, file, _("File System"), GEDIT_FILE_BOOKMARKS_STORE_IS_ROOT, NULL);
 	g_object_unref (file);
-	
+
 	check_mount_separator (model, GEDIT_FILE_BOOKMARKS_STORE_IS_ROOT, TRUE);
 }
 
@@ -249,50 +253,50 @@ get_fs_properties (gpointer    fs,
 	*flags = GEDIT_FILE_BOOKMARKS_STORE_IS_FS;
 	*name = NULL;
 	*pixbuf = NULL;
-	
+
 	if (G_IS_DRIVE (fs))
 	{
 		icon = g_drive_get_icon (G_DRIVE (fs));
 		*name = g_drive_get_name (G_DRIVE (fs));
-		
+
 		*flags |= GEDIT_FILE_BOOKMARKS_STORE_IS_DRIVE;
 	}
 	else if (G_IS_VOLUME (fs))
 	{
 		icon = g_volume_get_icon (G_VOLUME (fs));
 		*name = g_volume_get_name (G_VOLUME (fs));
-	
+
 		*flags |= GEDIT_FILE_BOOKMARKS_STORE_IS_VOLUME;
 	}
 	else if (G_IS_MOUNT (fs))
 	{
 		icon = g_mount_get_icon (G_MOUNT (fs));
 		*name = g_mount_get_name (G_MOUNT (fs));
-		
+
 		*flags |= GEDIT_FILE_BOOKMARKS_STORE_IS_MOUNT;
 	}
-	
+
 	if (icon)
 	{
 		*pixbuf = gedit_file_browser_utils_pixbuf_from_icon (icon, GTK_ICON_SIZE_MENU);
 		g_object_unref (icon);
 	}
 }
-		   
+
 
 static void
 add_fs (GeditFileBookmarksStore *model,
-	gpointer 		 fs,
-	guint 			 flags,
-	GtkTreeIter		*iter)
+	gpointer                 fs,
+	guint                    flags,
+	GtkTreeIter             *iter)
 {
 	gchar *name;
 	GdkPixbuf *pixbuf;
 	guint fsflags;
-	
+
 	get_fs_properties (fs, &name, &pixbuf, &fsflags);
 	add_node (model, pixbuf, name, fs, flags | fsflags, iter);
-	
+
 	if (pixbuf)
 		g_object_unref (pixbuf);
 
@@ -301,13 +305,13 @@ add_fs (GeditFileBookmarksStore *model,
 }
 
 static void
-process_volume_cb (GVolume 		   *volume,
+process_volume_cb (GVolume                 *volume,
 		   GeditFileBookmarksStore *model)
 {
 	GMount *mount;
 	guint flags = GEDIT_FILE_BOOKMARKS_STORE_NONE;
 	mount = g_volume_get_mount (volume);
-	
+
 	/* CHECK: should we use the LOCAL/REMOTE thing still? */
 	if (mount)
 	{
@@ -325,22 +329,20 @@ process_volume_cb (GVolume 		   *volume,
 
 static void
 process_drive_novolumes (GeditFileBookmarksStore *model,
-			 GDrive			 *drive)
+			 GDrive                  *drive)
 {
 	if (g_drive_is_media_removable (drive) &&
 	   !g_drive_is_media_check_automatic (drive) &&
 	    g_drive_can_poll_for_media (drive))
-	{
-		/* This can be the case for floppy drives or other 
+		/* This can be the case for floppy drives or other
 		   drives where media detection fails. We show the
 		   drive and poll for media when the user activates
 		   it */
 		add_fs (model, drive, GEDIT_FILE_BOOKMARKS_STORE_NONE, NULL);
-	}
 }
 
 static void
-process_drive_cb (GDrive   	          *drive,
+process_drive_cb (GDrive                  *drive,
 	          GeditFileBookmarksStore *model)
 {
 	GList *volumes;
@@ -356,14 +358,14 @@ process_drive_cb (GDrive   	          *drive,
 	else
 	{
 		process_drive_novolumes (model, drive);
-	}	
+	}
 }
 
 static void
 init_drives (GeditFileBookmarksStore *model)
 {
 	GList *drives;
-		
+
 	drives = g_volume_monitor_get_connected_drives (model->priv->volume_monitor);
 
 	g_list_foreach (drives, (GFunc)process_drive_cb, model);
@@ -372,19 +374,19 @@ init_drives (GeditFileBookmarksStore *model)
 }
 
 static void
-process_volume_nodrive_cb (GVolume 		   *volume,
+process_volume_nodrive_cb (GVolume                 *volume,
 			   GeditFileBookmarksStore *model)
 {
 	GDrive *drive;
-	
+
 	drive = g_volume_get_drive (volume);
-	
+
 	if (drive)
 	{
 		g_object_unref (drive);
 		return;
 	}
-	
+
 	process_volume_cb (volume, model);
 }
 
@@ -392,49 +394,46 @@ static void
 init_volumes (GeditFileBookmarksStore *model)
 {
 	GList *volumes;
-		
+
 	volumes = g_volume_monitor_get_volumes (model->priv->volume_monitor);
-	
+
 	g_list_foreach (volumes, (GFunc)process_volume_nodrive_cb, model);
 	g_list_foreach (volumes, (GFunc)g_object_unref, NULL);
 	g_list_free (volumes);
 }
 
 static void
-process_mount_novolume_cb (GMount 		   *mount,
+process_mount_novolume_cb (GMount                  *mount,
 			   GeditFileBookmarksStore *model)
 {
 	GVolume *volume;
-	
+
 	volume = g_mount_get_volume (mount);
-	
+
 	if (volume)
-	{
 		g_object_unref (volume);
-	}
-	else
-	{
+	else if (!g_mount_is_shadowed (mount))
 		/* Add the mount */
 		add_fs (model, mount, GEDIT_FILE_BOOKMARKS_STORE_NONE, NULL);
-	}
 }
 
 static void
 init_mounts (GeditFileBookmarksStore *model)
 {
 	GList *mounts;
-		
+
 	mounts = g_volume_monitor_get_mounts (model->priv->volume_monitor);
-	
+
 	g_list_foreach (mounts, (GFunc)process_mount_novolume_cb, model);
 	g_list_foreach (mounts, (GFunc)g_object_unref, NULL);
 	g_list_free (mounts);
 }
 
 static void
-init_fs (GeditFileBookmarksStore * model)
+init_fs (GeditFileBookmarksStore *model)
 {
-	if (model->priv->volume_monitor == NULL) {
+	if (model->priv->volume_monitor == NULL)
+	{
 		const gchar **ptr;
 		const gchar *signals[] = {
 			"drive-connected", "drive-changed", "drive-disconnected",
@@ -442,10 +441,10 @@ init_fs (GeditFileBookmarksStore * model)
 			"mount-added", "mount-removed", "mount-changed",
 			NULL
 		};
-		
+
 		model->priv->volume_monitor = g_volume_monitor_get ();
 
-		/* Connect signals */		
+		/* Connect signals */
 		for (ptr = signals; *ptr; ptr++)
 		{
 			g_signal_connect (model->priv->volume_monitor,
@@ -456,41 +455,40 @@ init_fs (GeditFileBookmarksStore * model)
 
 	/* First go through all the connected drives */
 	init_drives (model);
-	
+
 	/* Then add all volumes, not associated with a drive */
 	init_volumes (model);
-	
+
 	/* Then finally add all mounts that have no volume */
 	init_mounts (model);
 }
 
 static gboolean
-add_bookmark (GeditFileBookmarksStore * model, 
-	      gchar const * name,
-	      gchar const * uri)
+add_bookmark (GeditFileBookmarksStore *model,
+	      gchar const             *name,
+	      gchar const             *uri)
 {
-	GFile * file;
+	GFile *file;
 	gboolean ret;
 	guint flags = GEDIT_FILE_BOOKMARKS_STORE_IS_BOOKMARK;
 	GtkTreeIter iter;
-	
+
 	file = g_file_new_for_uri (uri);
-	
-	if (g_file_is_native (file)) {
+
+	if (g_file_is_native (file))
 		flags |= GEDIT_FILE_BOOKMARKS_STORE_IS_LOCAL_BOOKMARK;
-	} else {
+	else
 		flags |= GEDIT_FILE_BOOKMARKS_STORE_IS_REMOTE_BOOKMARK;
-	}
 
 	ret = add_file (model, file, name, flags, &iter);
 
 	g_object_unref (file);
-	
+
 	return ret;
 }
 
 static void
-init_bookmarks (GeditFileBookmarksStore * model)
+init_bookmarks (GeditFileBookmarksStore *model)
 {
 	gchar *bookmarks;
 	GError *error = NULL;
@@ -504,29 +502,40 @@ init_bookmarks (GeditFileBookmarksStore * model)
 				      ".gtk-bookmarks",
 				      NULL);
 
-	if (g_file_get_contents (bookmarks, &contents, NULL, &error)) {
+	if (g_file_get_contents (bookmarks, &contents, NULL, &error))
+	{
 		lines = g_strsplit (contents, "\n", 0);
 
-		for (line = lines; *line; ++line) {
-			if (**line) {
+		for (line = lines; *line; ++line)
+		{
+			if (**line)
+			{
+				GFile *location;
+
 				gchar *pos;
 				gchar *name;
 
 				/* CHECK: is this really utf8? */
 				pos = g_utf8_strchr (*line, -1, ' ');
 
-				if (pos != NULL) {
+				if (pos != NULL)
+				{
 					*pos = '\0';
 					name = pos + 1;
-				} else {
+				}
+				else
+				{
 					name = NULL;
 				}
 
 				/* the bookmarks file should contain valid
 				 * URIs, but paranoia is good */
-				if (gedit_utils_is_valid_uri (*line)) {
+				location = g_file_new_for_uri (*line);
+				if (gedit_utils_is_valid_location (location))
+				{
 					added |= add_bookmark (model, name, *line);
 				}
+				g_object_unref (location);
 			}
 		}
 
@@ -534,24 +543,28 @@ init_bookmarks (GeditFileBookmarksStore * model)
 		g_free (contents);
 
 		/* Add a watch */
-		if (model->priv->bookmarks_monitor == NULL) {
-			GFile * file;
+		if (model->priv->bookmarks_monitor == NULL)
+		{
+			GFile *file;
 
 			file = g_file_new_for_path (bookmarks);
 			model->priv->bookmarks_monitor = g_file_monitor_file (file, G_FILE_MONITOR_NONE, NULL, NULL);
 			g_object_unref (file);
 
-			g_signal_connect (model->priv->bookmarks_monitor, 
-					  "changed", 
-					  (GCallback)on_bookmarks_file_changed, 
+			g_signal_connect (model->priv->bookmarks_monitor,
+					  "changed",
+					  G_CALLBACK (on_bookmarks_file_changed),
 					  model);
 		}
-	} else {
+	}
+	else
+	{
 		/* The bookmarks file doesn't exist (which is perfectly fine) */
 		g_error_free (error);
 	}
 
-	if (added) {
+	if (added)
+	{
 		/* Bookmarks separator */
 		add_node (model, NULL, NULL, NULL,
 			  GEDIT_FILE_BOOKMARKS_STORE_IS_BOOKMARK |
@@ -572,7 +585,7 @@ static gint flags_order[] = {
 };
 
 static gint
-utf8_casecmp (gchar const *s1, const gchar * s2)
+utf8_casecmp (gchar const *s1, const gchar *s2)
 {
 	gchar *n1;
 	gchar *n2;
@@ -590,8 +603,9 @@ utf8_casecmp (gchar const *s1, const gchar * s2)
 }
 
 static gint
-bookmarks_compare_names (GtkTreeModel * model, GtkTreeIter * a,
-			 GtkTreeIter * b)
+bookmarks_compare_names (GtkTreeModel *model,
+			 GtkTreeIter  *a,
+			 GtkTreeIter  *b)
 {
 	gchar *n1;
 	gchar *n2;
@@ -628,8 +642,9 @@ bookmarks_compare_names (GtkTreeModel * model, GtkTreeIter * a,
 }
 
 static gint
-bookmarks_compare_flags (GtkTreeModel * model, GtkTreeIter * a,
-			 GtkTreeIter * b)
+bookmarks_compare_flags (GtkTreeModel *model,
+			 GtkTreeIter  *a,
+			 GtkTreeIter  *b)
 {
 	guint f1;
 	guint f2;
@@ -645,14 +660,17 @@ bookmarks_compare_flags (GtkTreeModel * model, GtkTreeIter * a,
 			    GEDIT_FILE_BOOKMARKS_STORE_COLUMN_FLAGS, &f2,
 			    -1);
 
-	for (flags = flags_order; *flags != -1; ++flags) {
-		if ((f1 & *flags) != (f2 & *flags)) {
-			if (f1 & *flags) {
+	for (flags = flags_order; *flags != -1; ++flags)
+	{
+		if ((f1 & *flags) != (f2 & *flags))
+		{
+			if (f1 & *flags)
 				return -1;
-			} else {
+			else
 				return 1;
-			}
-		} else if ((f1 & *flags) && (f1 & sep) != (f2 & sep)) {
+		}
+		else if ((f1 & *flags) && (f1 & sep) != (f2 & sep))
+		{
 			if (f1 & sep)
 				return -1;
 			else
@@ -664,8 +682,10 @@ bookmarks_compare_flags (GtkTreeModel * model, GtkTreeIter * a,
 }
 
 static gint
-bookmarks_compare_func (GtkTreeModel * model, GtkTreeIter * a,
-			GtkTreeIter * b, gpointer user_data)
+bookmarks_compare_func (GtkTreeModel *model,
+			GtkTreeIter  *a,
+			GtkTreeIter  *b,
+			gpointer      user_data)
 {
 	gint result;
 
@@ -678,42 +698,48 @@ bookmarks_compare_func (GtkTreeModel * model, GtkTreeIter * a,
 }
 
 static gboolean
-find_with_flags (GtkTreeModel * model, GtkTreeIter * iter, gpointer obj,
-		 guint flags, guint notflags)
+find_with_flags (GtkTreeModel *model,
+		 GtkTreeIter  *iter,
+		 gpointer      obj,
+		 guint         flags,
+		 guint         notflags)
 {
 	GtkTreeIter child;
 	guint childflags = 0;
- 	GObject * childobj;
+ 	GObject *childobj;
  	gboolean fequal;
-	
+
 	if (!gtk_tree_model_get_iter_first (model, &child))
 		return FALSE;
 
-	do {
+	do
+	{
 		gtk_tree_model_get (model, &child,
 				    GEDIT_FILE_BOOKMARKS_STORE_COLUMN_OBJECT,
 				    &childobj,
 				    GEDIT_FILE_BOOKMARKS_STORE_COLUMN_FLAGS,
 				    &childflags, -1);
-		
+
 		fequal = (obj == childobj);
-		
+
 		if (childobj)
 			g_object_unref (childobj);
-		 
+
 		if ((obj == NULL || fequal) &&
-		    (childflags & flags) == flags
-		    && !(childflags & notflags)) {
+		    (childflags & flags) == flags &&
+		    !(childflags & notflags))
+		{
 			*iter = child;
 			return TRUE;
 		}
-	} while (gtk_tree_model_iter_next (model, &child));
+	}
+	while (gtk_tree_model_iter_next (model, &child));
 
 	return FALSE;
 }
 
 static void
-remove_node (GtkTreeModel * model, GtkTreeIter * iter)
+remove_node (GtkTreeModel *model, GtkTreeIter *iter)
 {
 	guint flags;
 
@@ -721,31 +747,32 @@ remove_node (GtkTreeModel * model, GtkTreeIter * iter)
 			    GEDIT_FILE_BOOKMARKS_STORE_COLUMN_FLAGS, &flags,
 			    -1);
 
-	if (!(flags & GEDIT_FILE_BOOKMARKS_STORE_IS_SEPARATOR)) {
-		if (flags & GEDIT_FILE_BOOKMARKS_STORE_IS_FS) {
-			check_mount_separator (GEDIT_FILE_BOOKMARKS_STORE (model),
-			     		       flags & GEDIT_FILE_BOOKMARKS_STORE_IS_FS,
-					       FALSE);
-		}
+	if (!(flags & GEDIT_FILE_BOOKMARKS_STORE_IS_SEPARATOR) &&
+	    flags & GEDIT_FILE_BOOKMARKS_STORE_IS_FS)
+	{
+		check_mount_separator (GEDIT_FILE_BOOKMARKS_STORE (model),
+				       flags & GEDIT_FILE_BOOKMARKS_STORE_IS_FS,
+				       FALSE);
 	}
 
 	gtk_tree_store_remove (GTK_TREE_STORE (model), iter);
 }
 
 static void
-remove_bookmarks (GeditFileBookmarksStore * model)
+remove_bookmarks (GeditFileBookmarksStore *model)
 {
 	GtkTreeIter iter;
 
 	while (find_with_flags (GTK_TREE_MODEL (model), &iter, NULL,
 				GEDIT_FILE_BOOKMARKS_STORE_IS_BOOKMARK,
-				0)) {
+				0))
+	{
 		remove_node (GTK_TREE_MODEL (model), &iter);
 	}
 }
 
 static void
-initialize_fill (GeditFileBookmarksStore * model)
+initialize_fill (GeditFileBookmarksStore *model)
 {
 	init_special_directories (model);
 	init_fs (model);
@@ -781,23 +808,23 @@ gedit_file_bookmarks_store_new (void)
 	return model;
 }
 
-gchar *
-gedit_file_bookmarks_store_get_uri (GeditFileBookmarksStore * model,
-				    GtkTreeIter * iter)
+GFile *
+gedit_file_bookmarks_store_get_location (GeditFileBookmarksStore *model,
+					 GtkTreeIter             *iter)
 {
-	GObject * obj;
-	GFile * file = NULL;
+	GObject *obj;
+	GFile *file = NULL;
 	guint flags;
-	gchar * ret = NULL;
+	GFile * ret = NULL;
 	gboolean isfs;
-	
+
 	g_return_val_if_fail (GEDIT_IS_FILE_BOOKMARKS_STORE (model), NULL);
 	g_return_val_if_fail (iter != NULL, NULL);
 
 	gtk_tree_model_get (GTK_TREE_MODEL (model), iter,
 			    GEDIT_FILE_BOOKMARKS_STORE_COLUMN_FLAGS,
 			    &flags,
-			    GEDIT_FILE_BOOKMARKS_STORE_COLUMN_OBJECT, 
+			    GEDIT_FILE_BOOKMARKS_STORE_COLUMN_OBJECT,
 			    &obj,
 			    -1);
 
@@ -805,37 +832,33 @@ gedit_file_bookmarks_store_get_uri (GeditFileBookmarksStore * model,
 		return NULL;
 
 	isfs = (flags & GEDIT_FILE_BOOKMARKS_STORE_IS_FS);
-	
+
 	if (isfs && (flags & GEDIT_FILE_BOOKMARKS_STORE_IS_MOUNT))
-	{
 		file = g_mount_get_root (G_MOUNT (obj));
-	}
 	else if (!isfs)
-	{
 		file = g_object_ref (obj);
-	}
-	
+
 	g_object_unref (obj);
-	
+
 	if (file)
 	{
-		ret = g_file_get_uri (file);
+		ret = g_file_dup (file);
 		g_object_unref (file);
 	}
-	
+
 	return ret;
 }
 
 void
-gedit_file_bookmarks_store_refresh (GeditFileBookmarksStore * model)
+gedit_file_bookmarks_store_refresh (GeditFileBookmarksStore *model)
 {
 	gtk_tree_store_clear (GTK_TREE_STORE (model));
 	initialize_fill (model);
 }
 
 static void
-on_fs_changed (GVolumeMonitor 	      *monitor,
-	       GObject 		      *object,
+on_fs_changed (GVolumeMonitor          *monitor,
+	       GObject                 *object,
 	       GeditFileBookmarksStore *model)
 {
 	GtkTreeModel *tree_model = GTK_TREE_MODEL (model);
@@ -846,34 +869,35 @@ on_fs_changed (GVolumeMonitor 	      *monitor,
 	/* clear all fs items */
 	while (find_with_flags (tree_model, &iter, NULL, flags, noflags))
 		remove_node (tree_model, &iter);
-	
+
 	/* then reinitialize */
 	init_fs (model);
 }
 
 static void
-on_bookmarks_file_changed (GFileMonitor * monitor,
-			   GFile * file,
-			   GFile * other_file,
-			   GFileMonitorEvent event_type,
-			   GeditFileBookmarksStore * model)
+on_bookmarks_file_changed (GFileMonitor            *monitor,
+			   GFile                   *file,
+			   GFile                   *other_file,
+			   GFileMonitorEvent        event_type,
+			   GeditFileBookmarksStore *model)
 {
-	switch (event_type) {
-	case G_FILE_MONITOR_EVENT_CHANGED:
-	case G_FILE_MONITOR_EVENT_CREATED:
-		/* Re-initialize bookmarks */
-		remove_bookmarks (model);
-		init_bookmarks (model);
-		break;
-	case G_FILE_MONITOR_EVENT_DELETED: // FIXME: shouldn't we also monitor the directory?
-		/* Remove bookmarks */
-		remove_bookmarks (model);
-		g_object_unref (monitor);
-		model->priv->bookmarks_monitor = NULL;
-		break;
-	default:
-		break;
+	switch (event_type)
+	{
+		case G_FILE_MONITOR_EVENT_CHANGED:
+		case G_FILE_MONITOR_EVENT_CREATED:
+			/* Re-initialize bookmarks */
+			remove_bookmarks (model);
+			init_bookmarks (model);
+			break;
+		/*  FIXME: shouldn't we also monitor the directory? */
+		case G_FILE_MONITOR_EVENT_DELETED:
+			/* Remove bookmarks */
+			remove_bookmarks (model);
+			g_object_unref (monitor);
+			model->priv->bookmarks_monitor = NULL;
+			break;
+		default:
+			break;
 	}
 }
-
-// ex:ts=8:noet:
+/* ex:ts=8:noet: */
