@@ -54,13 +54,14 @@ enum
 	GEDIT_FILE_BOOKMARKS_STORE_IS_HOME         	= 1 << 2,  /* The special Home user directory */
 	GEDIT_FILE_BOOKMARKS_STORE_IS_DESKTOP      	= 1 << 3,  /* The special Desktop user directory */
 	GEDIT_FILE_BOOKMARKS_STORE_IS_DOCUMENTS    	= 1 << 4,  /* The special Documents user directory */
-	GEDIT_FILE_BOOKMARKS_STORE_IS_MOUNT        	= 1 << 5,  /* A mount point on file:// */
-	GEDIT_FILE_BOOKMARKS_STORE_IS_REMOTE_MOUNT 	= 1 << 6,  /* A remote mount point (ssh://) */
-	GEDIT_FILE_BOOKMARKS_STORE_IS_LOCAL_MOUNT 	= 1 << 7,  /* A remote mount point (ssh://) */
-	GEDIT_FILE_BOOKMARKS_STORE_IS_ROOT         	= 1 << 8,  /* The root file system (file:///) */
-	GEDIT_FILE_BOOKMARKS_STORE_IS_BOOKMARK     	= 1 << 9,  /* A gtk bookmark */
-	GEDIT_FILE_BOOKMARKS_STORE_IS_REMOTE_BOOKMARK	= 1 << 10, /* A remote gtk bookmark */
-	GEDIT_FILE_BOOKMARKS_STORE_IS_LOCAL_BOOKMARK	= 1 << 11  /* A local gtk bookmark */
+	GEDIT_FILE_BOOKMARKS_STORE_IS_FS        	= 1 << 5,  /* A mount object */
+	GEDIT_FILE_BOOKMARKS_STORE_IS_MOUNT        	= 1 << 6,  /* A mount object */
+	GEDIT_FILE_BOOKMARKS_STORE_IS_VOLUME        	= 1 << 7,  /* A volume object */
+	GEDIT_FILE_BOOKMARKS_STORE_IS_DRIVE        	= 1 << 8,  /* A drive object */
+	GEDIT_FILE_BOOKMARKS_STORE_IS_ROOT         	= 1 << 9,  /* The root file system (file:///) */
+	GEDIT_FILE_BOOKMARKS_STORE_IS_BOOKMARK     	= 1 << 10,  /* A gtk bookmark */
+	GEDIT_FILE_BOOKMARKS_STORE_IS_REMOTE_BOOKMARK	= 1 << 11, /* A remote gtk bookmark */
+	GEDIT_FILE_BOOKMARKS_STORE_IS_LOCAL_BOOKMARK	= 1 << 12  /* A local gtk bookmark */
 };
 
 struct _GeditFileBookmarksStore 
@@ -75,15 +76,15 @@ struct _GeditFileBookmarksStoreClass
 	GtkTreeStoreClass parent_class;
 };
 
-GType gedit_file_bookmarks_store_get_type               (void) G_GNUC_CONST;
-GType gedit_file_bookmarks_store_register_type          (GTypeModule * module);
+GType			 gedit_file_bookmarks_store_get_type		(void) G_GNUC_CONST;
+GType			 gedit_file_bookmarks_store_register_type	(GTypeModule             *module);
 
-GeditFileBookmarksStore *gedit_file_bookmarks_store_new (void);
-gchar *gedit_file_bookmarks_store_get_uri               (GeditFileBookmarksStore * model,
-					                 GtkTreeIter * iter);
-void gedit_file_bookmarks_store_refresh                 (GeditFileBookmarksStore * model);
+GeditFileBookmarksStore	*gedit_file_bookmarks_store_new			(void);
+GFile			*gedit_file_bookmarks_store_get_location	(GeditFileBookmarksStore *model,
+									 GtkTreeIter             *iter);
+void			 gedit_file_bookmarks_store_refresh		(GeditFileBookmarksStore *model);
 
 G_END_DECLS
-#endif				/* __GEDIT_FILE_BOOKMARKS_STORE_H__ */
 
-// ex:ts=8:noet:
+#endif /* __GEDIT_FILE_BOOKMARKS_STORE_H__ */
+/* ex:ts=8:noet: */
